#CHAPTER 1: Beyond NHST
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("ggplot2", "car", "ez", 
          "dplyr", "semTools", "meta")
PacMan(pkgs)
#
#Set working directory if needed
#Code provides example, but you will need to check 
#location of your project and 
#replace section in quotation marks
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import SalaryData
SalaryData <- read.csv("Salary_data2.csv",
                       header=TRUE, 
                       na.strings=c("NA", " ", ""))
#
#Perform Between-Subjects One-Way ANOVA----
ezResult <- ezANOVA(data=SalaryData, 
                    dv=Wk_salaryDollar, wid= ID, 
                    between=race_ethnicity, type=3, 
                    detailed=TRUE, return_aov=TRUE)
ezResult
#
#Post-hoc comparison
TukeyHSD(ezResult$aov)
#
#Descriptives by Group
DescByGrp <- SalaryData %>% 
  group_by(race_ethnicity) %>%
  summarize(N=n(),
            mean=round(mean(Wk_salaryDollar), 4),
            sd=round(sd(Wk_salaryDollar), 4),
            se=round(sd/sqrt(N), 4),
            median=round(median(Wk_salaryDollar), 2),
            skew_Z=round(skew(Wk_salaryDollar)[3], 4),
            skew_p=round(skew(Wk_salaryDollar)[4], 4),
            kurt_Z=round(kurtosis(Wk_salaryDollar)[3], 4), 
            kurt_p=round(kurtosis(Wk_salaryDollar)[4], 4))
#
#Error Bars by Group (ethnicity)
ggplot(DescByGrp, aes(x=race_ethnicity, y=mean))+
  geom_errorbar(aes(ymin=mean-(se*(qt(.975, N-1))),
                    ymax=mean+(se*(qt(.975, N-1)))), width=.2)+
  geom_point(size=2) +
  theme_classic()+
  labs(title="Average Weekly Salary by Ethnicity", 
       subtitle="with 95% CI", x="Ethnicity", y="$")+
  theme(axis.ticks.x=element_blank(),
        plot.title=element_text(hjust=.5),
        plot.subtitle=element_text(hjust=.5))
#
#Bar chart of diff scores
TukeyOut <- TukeyHSD(ezResult$aov)
ChartEx <- data.frame(EthnicComp=rownames(TukeyOut$race_ethnicity[1:4,]), 
                      TukeyOut$race_ethnicity[1:4,1:3], row.names = NULL)
ggplot(ChartEx, aes(x=EthnicComp, y=diff, fill=EthnicComp)) +
  geom_bar(stat="identity") +
  geom_errorbar(aes(ymin=lwr, ymax=upr), width=.2) +
  scale_fill_brewer("Ethnic Comparison",palette="Dark2") +
  theme_classic()+
  labs(title="Avg Weekly Salary Diff by Ethnicity", 
       subtitle="with 95% CI", x="Ethnicity", y="$")+
  theme(axis.ticks.x=element_blank(),
        axis.text.x = element_blank(),
        plot.title=element_text(hjust=.5),
        plot.subtitle=element_text(hjust=.5))
#
#Performing Meta-analysis----
metaData <- read.csv("Metaanalysis_Data.csv")
View(metaData)
#
#The install and library calls should not be needed, but
#they serve as a reminder about the package being used
#and how to install and attach packages
install.packages("meta", 
                 dependencies=TRUE)
library(meta)
#
#Perform meta-analysis with continuous DV
metaOut <- metacont(n.e=n_txp, mean.e=M_txp, sd.e=SD_txp,
                    n.c=n_con, mean.c=M_con, sd.c=SD_con, 
                    data=metaData, studlab=Author,
                    method.smd="Cohen", pooledvar=TRUE)
forest(metaOut, digits.sd=2)
