#CHAPTER 3: WARNER Appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "ggplot2", "dplyr", "ppcor")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import WARNER Vocab and Height data----
VocHeight <- read.spss("Warner/vocheightgrade.sav", 
                   to.data.frame=TRUE)
names(VocHeight)
View(VocHeight)
#
#Examine scatterplot----
ggplot(VocHeight, aes(x=height,y=vocabulary))+
  geom_point(size=2, alpha=.8, 
             aes(shape=factor(grade)))+
  theme_classic() +
  labs(shape="Grade")+
  geom_smooth(method=lm, color="black", 
              fill="blue")
#
#Overall correlation between height and vocabulary----
cor.test(VocHeight$height, VocHeight$vocabulary, 
         method="pearson")
#
#Correlation: Height and Voc by Grade----
CorrFun <- function(x, y, meth){
  corrOut <- cor.test(x=x, y=y, method=meth) 
  cbind(corrOut$estimate, corrOut$statistic, corrOut$parameter, corrOut$p.value)}
#
CorrByGrade <- VocHeight %>% group_by(grade) %>% 
  summarize(Cor= CorrFun(x=height, y=vocabulary, meth="pearson")[,1], 
            t=CorrFun(x=height, y=vocabulary, meth="pearson")[,2], 
            df=CorrFun(x=height, y=vocabulary, meth="pearson")[,3], 
            p=CorrFun(x=height, y=vocabulary, meth="pearson")[,4],
            Mean=mean(vocabulary),
            StDev=sd(vocabulary))
View(CorrByGrade)
#
#Partial correlations----
#Generate Residuals for height from grade
HtGrade <- lm(height~grade, data=VocHeight)
VocHeight$Resid_Height <- HtGrade$residuals
#
#Generate Residuals for vocabulary from grade
VocGrade <- lm(vocabulary~grade, data=VocHeight)
VocHeight$Resid_Voc <- VocGrade$residuals
#
#Check updated data frame
View(VocHeight)
#
#Bivariate Pearson correlation with residuals
cor.test(VocHeight$Resid_Height, 
         VocHeight$Resid_Voc, method="pearson")
#
#Alternative approach for partial corr
pcor.test(x=VocHeight$height, 
          y=VocHeight$vocabulary, 
          z=VocHeight$grade, 
          method="pearson")
