#CHAPTER 3: Statistical Control
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("ggplot2", "dplyr", "ppcor")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Disclosure and Satisfaction data----
RelSat_DF <- read.csv("Avo_Disc_RelSat.csv", 
                      header=TRUE, 
                      na.strings=c("NA", " ", ""))
names(RelSat_DF)
View(RelSat_DF)
#
#Examine scatterplot----
#Organize levels of AttAvo_cat
levels(RelSat_DF$AttAvo_cat)
RelSat_DF$AttAvo_cat <- factor(RelSat_DF$AttAvo_cat, 
          levels(RelSat_DF$AttAvo_cat)[c(3,1,2)])
#Scatterplot: Lines by group
ggplot(RelSat_DF, aes(x=Disclosure,y=RelSat))+
  geom_point(size=2, alpha=.5, 
             aes(shape=factor(AttAvo_cat)))+
  theme_classic() + labs(shape="Avoidance")+
  geom_smooth(method=lm, color="black",
              aes(fill=AttAvo_cat))
#Scatterplot: Overall fit
ggplot(RelSat_DF, aes(x=Disclosure,y=RelSat))+
  geom_point(size=2, alpha=.5, 
             aes(shape=factor(AttAvo_cat)))+
  theme_classic() + labs(shape="Avoidance")+
  geom_smooth(method=lm, color="black", fill="blue")
#
#Overall correlation between Disclosure and Rel. Sat.----
cor.test(RelSat_DF$RelSat, RelSat_DF$Disclosure, 
         method="pearson")
#
#Correlation: Disclosure, Rel. Sat. by Att Avo----
CorrFun <- function(x, y, meth){
  corrOut <- cor.test(x=x, y=y, method=meth) 
  cbind(corrOut$estimate, corrOut$statistic, corrOut$parameter, corrOut$p.value)}
#
CorrByAttAvo <- RelSat_DF %>% group_by(AttAvo_cat) %>% 
  summarize(Cor= CorrFun(x=Disclosure, y=RelSat, meth="pearson")[,1], 
            t=CorrFun(x=Disclosure, y=RelSat, meth="pearson")[,2], 
            df=CorrFun(x=Disclosure, y=RelSat, meth="pearson")[,3], 
            p=CorrFun(x=Disclosure, y=RelSat, meth="pearson")[,4],
            Mean=mean(RelSat),
            StDev=sd(RelSat))
View(CorrByAttAvo)
#
#Partial correlations----
#Generate Residuals for disclosure from ECRRS_AVO
DiscECRRS_AVO <- lm(Disclosure~ECRRS_AVO, data=RelSat_DF)
RelSat_DF$Resid_Disclosure <- DiscECRRS_AVO$residuals
#
#Generate Residuals for vocabulary from grade
RelSatECRRS_AVO <- lm(RelSat~ECRRS_AVO, data=RelSat_DF)
RelSat_DF$Resid_RelSat <- RelSatECRRS_AVO$residuals
#
#Check updated data frame
View(RelSat_DF)
#
#Bivariate Pearson correlation with residuals
cor.test(RelSat_DF$Resid_Disclosure, 
         RelSat_DF$Resid_RelSat, method="pearson")
#
#Alternative approach for partial corr
pcor.test(x=RelSat_DF$Disclosure, 
          y=RelSat_DF$RelSat, 
          z=RelSat_DF$ECRRS_AVO, 
          method="pearson")
