#CHAPTER 4: WARNER Appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "scatterplot3d", "rgl")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import WARNER Age, Wt, Blood pressure data----
AgeWtBp <- read.spss("Warner/ageweightbp.sav", 
                       to.data.frame=TRUE)
names(AgeWtBp)
View(AgeWtBp)
#
#Scatterplots----
#3D scatterplots - stationary
ScatAgeWtBp <- scatterplot3d(x=AgeWtBp$Age, y=AgeWtBp$BloodPressure, 
              z=AgeWtBp$Weight, 
              main="Blood Pressure by Age and Weight", 
              xlab="Age", ylab="Blood Pressure", 
              zlab="Weight", box=TRUE, type="h")
ScatPlane <- lm(BloodPressure~Age+Weight, data=AgeWtBp)
ScatAgeWtBp$plane3d(ScatPlane)
#
#3D scatterplot - rotates
plot3d(x=AgeWtBp$Age, y=AgeWtBp$BloodPressure, 
       z=AgeWtBp$Weight, xlab="Age", ylab="Blood Pressure", 
       zlab="Weight")
#
#Scatterplot matrix
pairs(AgeWtBp, upper.panel = NULL)
pairs(AgeWtBp[,1:3], upper.panel = NULL)
#
#Regression----
Bp_RegMod <- 
  lm(BloodPressure~Age+Weight, 
      data=AgeWtBp)
print(summary.lm(Bp_RegMod), 
      digits=4)
#
#Semipartial correlations----
resAge <- residuals(lm(Age~Weight, 
                       data=AgeWtBp))
round(cor(AgeWtBp$BloodPressure, 
    resAge)^2, 2)
resWt <- residuals(lm(Weight~Age, 
                      data=AgeWtBp))
round(cor(AgeWtBp$BloodPressure, 
    resWt)^2, 2)
#
#Plot residuals and predicted values----
RegPred <- predict(Bp_RegMod)
StdPred <- (RegPred-mean(RegPred))/
            sd(RegPred)
StdResid <- rstandard(Bp_RegMod)
plot(StdPred, StdResid)
abline(0,0)
