#CHAPTER 4: Stat Control with Regression
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("scatterplot3d", "rgl")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2/")
#
#Import Disclosure and Satisfaction data----
RelSat_DF <- read.csv("Avo_Disc_RelSat.csv", 
                      header=TRUE, 
                      na.strings=c("NA", " ", ""))
names(RelSat_DF)
View(RelSat_DF)
#
#Scatterplots----
#3D scatterplots - stationary
ScatRelSat_DF <- scatterplot3d(RelSat_DF$RelSat~
                                 RelSat_DF$Disclosure+
                                 RelSat_DF$ECRRS_AVO,
                               main="Relationship Satisfaction \n by Disclosure and Avoidance", 
                               xlab="Disclosure", ylab="Avoidance", 
                               zlab="Rel. Sat", box=TRUE)
ScatPlane <- lm(RelSat~Disclosure+ECRRS_AVO, data=RelSat_DF)
ScatRelSat_DF$plane3d(ScatPlane)
#
#3D scatterplot - rotates
plot3d(RelSat_DF$RelSat~
         RelSat_DF$Disclosure+
         RelSat_DF$ECRRS_AVO, 
       xlab="Disclosure", 
       ylab="Avoidance", 
       zlab="Rel. Sat.")
#
#Scatterplot matrix
pairs(RelSat_DF[,2:4], upper.panel = NULL)
#
#Regression----
RelSat_RegMod <- 
  lm(RelSat~Disclosure+ECRRS_AVO, 
     data=RelSat_DF)
print(summary.lm(RelSat_RegMod), 
      digits=4)
#
#Semipartial correlations----
resDisclosure <- residuals(lm(Disclosure~ECRRS_AVO, 
                       data=RelSat_DF))
round(cor(RelSat_DF$RelSat, 
          resDisclosure)^2, 2)
resAvo <- residuals(lm(ECRRS_AVO~Disclosure, 
                      data=RelSat_DF))
round(cor(RelSat_DF$RelSat, 
          resAvo)^2, 2)
#
#Plot residuals and predicted values----
RegPred <- predict(RelSat_RegMod)
StdPred <- (RegPred-mean(RegPred))/
  sd(RegPred)
StdResid <- rstandard(RelSat_RegMod)
plot(StdPred, StdResid)
abline(0,0)
