#CHAPTER 5: WARNER Appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "ppcor", "leaps", "caret")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import data----
Physics <- read.spss("Warner/predictphysics.sav", 
                     to.data.frame=TRUE)
names(Physics)
View(Physics)
#
#Standard Regression----
Phys_RegMod <- 
  lm(physics~gender+iq+ei+
  vsat+msat,data=Physics)
print(summary.lm(
  Phys_RegMod), digits=5)
#
#Semipartial correlations
#Prepare data
Physics2 <- na.omit(subset.data.frame(Physics, 
    select=c("physics", "gender", "iq", "ei", 
             "vsat", "msat")))
Physics2$gender <- as.numeric(Physics2$gender)
#
sr_gender <- spcor.test(
  Physics2$physics, Physics2$gender, 
  Physics2[,c("iq", "ei","msat", "vsat")])
sr_gender$estimate^2
sr_VSAT <- spcor.test(
  Physics2$physics, Physics2$vsat, 
  Physics2[,c("gender", "iq", "ei", "msat")])
sr_VSAT$estimate^2
sr_MSAT <- spcor.test(
  Physics2$physics, Physics2$msat, 
  Physics2[,c("gender", "iq", "ei", "vsat")])
sr_MSAT$estimate^2
#
#Plot residuals and predicted values
RegPred <- predict(Phys_RegMod)
StdPred <- (RegPred-mean(RegPred))/
  sd(RegPred)
StdResid <- rstandard(Phys_RegMod)
plot(StdPred, StdResid)
abline(0,0)
#
#User-determined regression----
Phys_RegMod1 <- 
  lm(physics~gender,
     data=Physics)
Phys_RegMod2 <- 
  lm(physics~gender+iq,
     data=Physics)
Phys_RegMod3 <- 
  lm(physics~gender+iq+ei,
     data=Physics)
Phys_RegMod4 <- 
  lm(physics~gender+iq+ei+vsat,
     data=Physics)
Phys_RegMod5 <- 
  lm(physics~gender+iq+ei+vsat+msat,
     data=Physics)
#
#Evaluate change at each step
anova(Phys_RegMod1)
anova(Phys_RegMod1, Phys_RegMod2)
anova(Phys_RegMod2, Phys_RegMod3)
anova(Phys_RegMod3, Phys_RegMod4)
anova(Phys_RegMod4, Phys_RegMod5)
#
#Data-driven regression----
stepMod <- train(physics~., data=Physics2, 
                 method="leapForward", 
                 tuneGrid=data.frame(nvmax=1:5))
stepMod$results
summary(stepMod$finalModel)
round(coef(stepMod$finalModel, 4), 3)
