#CHAPTER 5: Regression with Mult. Predictors
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("ppcor", "caret", "lm.beta")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Life Sat. data----
LifeSat_DF <- read.csv("LifeSat_predict.csv", 
                      header=TRUE, 
                      na.strings=c("NA", " ", ""))
names(LifeSat_DF)
View(LifeSat_DF)
#
#Standard Regression----
LifeSat_RegMod <- 
  lm(LifeSat~Gender+Happy+PosAffect+
    NegAffect+SexSat,data=LifeSat_DF)
print(summary.lm(
  LifeSat_RegMod), digits=5)
lm.beta(LifeSat_RegMod)
#
#Semipartial correlations
#Prepare data
LifeSat_DF2 <- subset.data.frame(
  LifeSat_DF, select=c(
    "LifeSat", "Gender", "Happy", 
    "PosAffect","NegAffect", "SexSat"))
LifeSat_DF2$Gender <- as.numeric(LifeSat_DF2$Gender)
#
semiPartCorr <- spcor(LifeSat_DF2)
View(semiPartCorr$estimate)
semiPartCorr_DF <- as.data.frame(round(
  semiPartCorr$estimate[1,]^2, 3))
View(semiPartCorr_DF)
#
#Plot residuals and predicted values
RegPred <- predict(LifeSat_RegMod)
StdPred <- (RegPred-mean(RegPred))/
  sd(RegPred)
StdResid <- rstandard(LifeSat_RegMod)
plot(StdPred, StdResid)
abline(0,0)
#
#User-determined regression----
LifeSat_RegMod1 <- 
  lm(LifeSat~Gender,
     data=LifeSat_DF2)
LifeSat_RegMod2 <- 
  lm(LifeSat~Gender+
       Happy+PosAffect+NegAffect,
     data=LifeSat_DF2)
LifeSat_RegMod3 <- 
  lm(LifeSat~Gender+
       Happy+PosAffect+NegAffect+
       SexSat,
     data=LifeSat_DF2)
#
#Evaluate change at each step
anova(LifeSat_RegMod1)
anova(LifeSat_RegMod1, LifeSat_RegMod2)
anova(LifeSat_RegMod2, LifeSat_RegMod3)
#
#Data-driven regression----
#Note you need to set the seed if you want
#identical results each time you use 
#the train function
set.seed(42)
#
stepMod <- train(
  LifeSat~Gender+Happy+PosAffect+
  NegAffect+SexSat, data=LifeSat_DF, 
  method="leapForward", 
  tuneGrid=data.frame(nvmax=1:5))
stepMod$results
summary(stepMod$finalModel)
round(coef(stepMod$finalModel, 5), 3)
