#CHAPTER 6: WARNER Appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "ggplot2", "ez", "dplyr")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import WARNER Salary, Sex, College data----
Salary_DF <- read.spss("Warner/Salary Sex College.sav", 
                     to.data.frame=TRUE)
names(Salary_DF)
View(Salary_DF)
#
#Checking assumptions----
#Histogram of outcome
ggplot(data=Salary_DF, aes(x=salary))+
  geom_histogram(position="identity", 
      alpha=0.8, binwidth=4, col="white")+
  theme_classic()
#Histogram by group
ggplot(data=Salary_DF, 
       aes(x=salary, fill=gender))+
  geom_histogram(position='identity', 
              alpha=0.8, binwidth=4)+
  scale_fill_manual(values=c(
    "#000099", "#990000"))+
  theme_classic()
#
#Boxplot: Salary by gender
ggplot(Salary_DF, aes(x=gender, y=salary))+
  geom_boxplot(notch = FALSE, width=.1, 
      outlier.size=.3, outlier.alpha=.7)+ 
  labs(title="Salary by Gender",
       x="Gender", y="Salary")+ 
  theme_classic() + 
  theme(axis.title = element_text(size = 12),
        legend.position = "none",
        plot.title=element_text(hjust=.5))
#
#Scatterplot: Salary by Yrs Exp with Gender
ggplot(Salary_DF, aes(x=years,y=salary))+
  geom_point(size=2, alpha=.5, 
             aes(shape=factor(gender)))+
  theme_classic() + labs(shape="Gender")
#
#Separate fit line for each gender
ggplot(Salary_DF, aes(x=years,y=salary))+
  geom_point(size=2, alpha=.5, 
          aes(shape=factor(gender)))+
  theme_classic() + labs(shape="Gender")+
  geom_smooth(method=lm, color="black", 
              aes(fill=gender))
#
#Between-Subjects One-Way ANOVA: Gender----
options(contrasts=c("contr.sum","contr.poly"))
Salary_DF$ID <- factor(row.names(Salary_DF))
ezResult <- ezANOVA(data=Salary_DF, 
  dv=salary, wid= ID, 
  between=gender, type=3, 
  detailed=TRUE, return_aov=TRUE)
ezResult
summary.aov(ezResult$aov)
#
#Descriptives by Gender
ciPercent <- 95
DescByGender <- Salary_DF %>% group_by(gender) %>% 
  summarize(N=n(),Mean=mean(salary),
            sd=sd(salary),se=sd/sqrt(N), 
            ci=se*(qt((ciPercent/100)/2+.5, N-1)),
            LL=round(Mean-ci, 3), 
            UL=round(Mean+ci, 3))
View(DescByGender)
#
#Between-Subjects One-Way ANOVA: College----
ezResult_Coll <- ezANOVA(data=Salary_DF, 
          dv=salary, wid=ID, 
          between=college, type=3, 
          detailed=TRUE, return_aov=TRUE)
ezResult_Coll
summary.aov(ezResult$aov)
#
#Descriptives by College Type
DescByCollege <- Salary_DF %>% group_by(college) %>% 
  summarize(N=n(),Mean=mean(salary),
            sd=sd(salary),se=sd/sqrt(N), 
            ci=se*(qt((ciPercent/100)/2+.5, N-1)),
            LL=round(Mean-ci, 3), 
            UL=round(Mean+ci, 3))
View(DescByCollege)
#
#Regressions----
#Dummy coding----
#Gender and salary
SalGender <- lm(salary~gender, 
                data=Salary_DF)
summary.lm(SalGender)
#
#College type and salary
SalCollType <- lm(
  salary~d1+d2, data=Salary_DF)
summary.lm(SalCollType)
#
#Effect coding----
#Gender and salary
SalGeneff <- lm(salary~geneff, 
                data=Salary_DF)
summary.lm(SalGeneff)
#
#College type and salary
SalColleff <- lm(
  salary~e1+e2, data=Salary_DF)
summary.lm(SalColleff)
#
#Orthogonal coding----
#College type and salary
SalCollOrth <- lm(
  salary~o1+o2, data=Salary_DF)
summary.lm(SalCollOrth)
#
#Reg with Quant and Dummy Vars----
SalGenExp <- lm(
  salary~years+gender, 
  data=Salary_DF)
summary.lm(SalGenExp)
