#CHAPTER 6: Dummy Variables
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("ggplot2", "ez", "dplyr", "dummies")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Relationship Satisfaction data----
RelSat_DF <- read.csv("Avo_Disc_RelSat.csv", 
                      header=TRUE, 
                      na.strings=c("NA", " ", ""))
names(RelSat_DF)
View(RelSat_DF)
#
#Checking assumptions----
##Histogram of Relationship Sat.----
ggplot(data=RelSat_DF, aes(x=RelSat))+
  geom_histogram(position="identity", 
      alpha=0.8, binwidth=4, col="white")+
  theme_classic()
#Histogram by group
ggplot(data=RelSat_DF, 
       aes(x=RelSat, fill=AttAvo_cat))+
  geom_histogram(position='identity', 
                 alpha=0.8, binwidth=4)+
  scale_fill_brewer(palette="Set1")+
  theme_classic()
#
##Boxplot: RelSat by AttAvo_cat----
#Change order of levels
levels(RelSat_DF$AttAvo_cat)
RelSat_DF$AttAvo_cat <- factor(RelSat_DF$AttAvo_cat, 
      levels(RelSat_DF$AttAvo_cat)[c(3,1,2)])
#
ggplot(RelSat_DF, aes(x=AttAvo_cat, y=RelSat))+
  geom_boxplot(notch = FALSE, width=.1, 
          outlier.size=1, outlier.alpha=.7, 
          outlier.color="red")+ 
  labs(title="Relationship Satisfaction",
       subtitle = "by Attachment Avoidance",
       x="Avoidance", y="Rel Sat")+ 
  theme_classic() + 
  theme(axis.title = element_text(size = 12),
        legend.position = "none",
        plot.title=element_text(hjust=.5), 
        plot.subtitle=element_text(hjust=.5))
#
##Scatterplot: RelSat by Disclosure with AttAvo_cat----
ggplot(RelSat_DF, aes(x=Disclosure,y=RelSat))+
  geom_point(size=2, alpha=.3, 
             aes(shape=factor(AttAvo_cat)))+
  theme_classic() + labs(shape="AttAvo_cat")
#
##Separate fit line for each AttAvo_cat----
ggplot(RelSat_DF, aes(x=Disclosure,y=RelSat))+
  geom_point(size=2, alpha=.3, 
             aes(shape=factor(AttAvo_cat)))+
  theme_classic() + labs(shape="AttAvo_cat")+
  geom_smooth(method=lm, color="black", 
              aes(fill=AttAvo_cat))
#
#Between-Subjects One-Way ANOVA: Att Avo----
options(contrasts=c("contr.sum","contr.poly"))
ezResult <- ezANOVA(data=RelSat_DF, 
              dv=RelSat, wid= ID, 
              between=AttAvo_cat, type=3, 
              detailed=TRUE, return_aov=TRUE)
ezResult
summary.aov(ezResult$aov)
#
##Descriptives by Att. Avoidance----
ciPercent <- 95
DescByAttAvo <- RelSat_DF %>% group_by(AttAvo_cat) %>% 
  summarize(N=n(),Mean=mean(RelSat),
      sd=sd(RelSat),se=sd/sqrt(N), 
      ci=se*(qt((ciPercent/100)/2+.5, N-1)),
      LL=round(Mean-ci, 3), 
      UL=round(Mean+ci, 3))
View(DescByAttAvo)
#
#Regressions----
##Dummy code variables---
AttAvo_dummy <- dummy(RelSat_DF$AttAvo_cat)
View(AttAvo_dummy)
RelSat_DF2 <- cbind.data.frame(RelSat_DF, AttAvo_dummy)
View(RelSat_DF2)
#
##Regression: Rel Sat by Attachment Avo - Dummy
RelSatReg_AvoDum <- lm(RelSat~AttAvo_catAvoidant+
          AttAvo_catSecure, data=RelSat_DF2)
summary.lm(RelSatReg_AvoDum)
#
##Effect code variables----
RelSat_DF2$AvgEff[RelSat_DF2$AttAvo_cat=="Secure"] <- -1
RelSat_DF2$AvgEff[RelSat_DF2$AttAvo_cat=="Avg"] <- 1
RelSat_DF2$AvgEff[RelSat_DF2$AttAvo_cat=="Avoidant"] <- 0
#
RelSat_DF2$AvoEff[RelSat_DF2$AttAvo_cat=="Secure"] <- -1
RelSat_DF2$AvoEff[RelSat_DF2$AttAvo_cat=="Avg"] <- 0
RelSat_DF2$AvoEff[RelSat_DF2$AttAvo_cat=="Avoidant"] <- 1
View(RelSat_DF2)
#
##Regression: Rel Sat by Attachment Avo - Effect
RelSatReg_AvoEff <- lm(RelSat~AvgEff+
            AvoEff, data=RelSat_DF2)
summary.lm(RelSatReg_AvoEff)
#
##Orthogonal code variables----
RelSat_DF2$AvgOrth[RelSat_DF2$AttAvo_cat=="Secure"] <- -1
RelSat_DF2$AvgOrth[RelSat_DF2$AttAvo_cat=="Avg"] <- 1
RelSat_DF2$AvgOrth[RelSat_DF2$AttAvo_cat=="Avoidant"] <- 0
#
RelSat_DF2$AvoOrth[RelSat_DF2$AttAvo_cat=="Secure" | RelSat_DF2$AttAvo_cat=="Avg"] <- 1
RelSat_DF2$AvoOrth[RelSat_DF2$AttAvo_cat=="Avoidant"] <- -2
#
##Regression: Rel Sat by Attachment Avo - Orthogonal
RelSatReg_AvoOrth <- lm(RelSat~AvgOrth+
                         AvoOrth, data=RelSat_DF2)
summary.lm(RelSatReg_AvoOrth)
#
#Regression: Quantitative and Dummy----
RelSatReg_DiscAvo <- lm(RelSat~Disclosure+
                          AvoOrth, RelSat_DF2)
summary.lm(RelSatReg_DiscAvo)
