#CHAPTER 7: WARNER Appendix
#Installing and attaching packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign","ggplot2", "ez", "dplyr", "sjPlot")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import WARNER Sex by Year no Int. data----
SexYr_DF <- read.spss("Warner/First example sex and college predict Salary.sav", 
                       to.data.frame=TRUE)
names(SexYr_DF)
View(SexYr_DF)
#
#Interaction Cat and Quant----
##Checking Assumptions----
#Scatterplot Salary and Yrs accounting for Sex
ggplot(na.omit(SexYr_DF), aes(x=years, 
          y=salary, color=sex, shape=sex)) +
  geom_point(size=2, alpha=.4) +
  theme_classic() + labs(y="Salary ($)") +
  geom_smooth(method=lm, aes(fill=sex))

#
##Performing Regression----
Sal_SexYr <- lm(salary~
          sex*years, 
          data=SexYr_DF)
Sal_SexYr2 <- lm(salary~
          sex+years+sexbyyears, 
          data=SexYr_DF)
Sal_SexYr3 <- lm(salary~
          sex+years+sex:years, 
          data=SexYr_DF)
summary.lm(Sal_SexYr)
summary.lm(Sal_SexYr2)
summary.lm(Sal_SexYr3)
#
#Dummy Vars----
#MODEL 1
Sal_CollYr_mod1 <- lm(salary~
          years+D1+D2, 
          data=SexYr_DF)
#MODEL 2
Sal_CollYr_mod2 <- lm(salary~
          years+D1+D2+
          D1byyears+D2byyears,
          data=SexYr_DF)
summary.lm(Sal_CollYr_mod1)
anova(Sal_CollYr_mod1, Sal_CollYr_mod2)
summary.lm(Sal_CollYr_mod2)
#
#Data with Interaction----
SexYr_wInt_DF <- read.spss(
"Warner/Second example significant interaction of sex by years.sav", 
    to.data.frame=TRUE)
#
#Regression with Interaction
Sal_SexYr_wInt <- lm(salary~
          sex*years, 
          data=SexYr_wInt_DF)
summary.lm(Sal_SexYr_wInt)
#
#Scatterplot
ggplot(na.omit(SexYr_wInt_DF), 
       aes(x=years, y=salary, 
          color=sex, shape=sex)) +
  geom_point(size=2, alpha=.4) +
  theme_classic() + 
  labs(y="Salary ($)") +
  geom_smooth(method=lm, 
              aes(fill=sex))
#
#Simple Main Effects
Sal_Sex <- lapply(split(SexYr_wInt_DF, SexYr_wInt_DF$sex),
       lm, formula=salary~years)
summary.lm(Sal_Sex$female)
summary.lm(Sal_Sex$male)
#
#Interaction with Two Quant----
#Import Data
HabitsAge_DF <- read.spss("Warner/Third example habits by age interaction.sav", 
                           to.data.frame=TRUE)
names(HabitsAge_DF)
#
#Center scores
M_age <- mean(HabitsAge_DF$age)
M_age
M_habits <- mean(HabitsAge_DF$habits)
M_habits
HabitsAge_DF$age_cent <- HabitsAge_DF$age-M_age
HabitsAge_DF$habits_cent <- HabitsAge_DF$habits-M_habits
View(HabitsAge_DF)
#
#Regression----
AgeByHab_Reg <- lm(symptoms~
        habits_cent*age_cent, 
        data=HabitsAge_DF)
summary.lm(AgeByHab_Reg)
#
#Graphing quant interaction
install.packages("sjPlot", 
          dependencies = TRUE)
library(sjPlot)
plot_model(AgeByHab_Reg,type="int", 
          mdrt.values="meansd")
