#CHAPTER 7: Moderation
#Installing and attaching packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("ggplot2", "ez", "dplyr", "rgl", "sjPlot")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Data----
SalaryData <- read.csv("Salary_data5.csv",
                       header=TRUE, na.strings=c("NA", " ", ""))
View(SalaryData)
#
#Interaction with 2 Categorical Variables----
##Checking Assumptions----
###Create histograms by cell---- 
#Create Women-NoGrad data frame (DF) 
WomenNoGradEd <- subset(SalaryData, 
                gender=="woman" & 
                  GradEd=="NoGrad")
#Produce Women-NoGrad histogram
ggplot(data=WomenNoGradEd, 
       aes(x=Wk_salaryDollar))+ 
  geom_histogram(position="identity", 
        binwidth=100, col="white")+ 
  theme_classic()+
  labs(title="Women - No Grad School")
#
#Create Women-GradEd DF
WomenGradEd <- subset(SalaryData, 
                       gender=="woman" &
                         GradEd=="Grad")
#Produce Women-GradEd histogram
ggplot(data=WomenGradEd, 
       aes(x=Wk_salaryDollar))+ 
  geom_histogram(position="identity", 
                 binwidth=100, col="white")+ 
  theme_classic()+
  labs(title="Women - Grad School")
#
#Create Men-NoGradEd DF
MenNoGradEd <- subset(SalaryData, 
                    gender=="man" &
                      GradEd=="NoGrad")
#Produce Men-NoGradEd histogram
ggplot(data=MenNoGradEd, 
       aes(x=Wk_salaryDollar))+ 
  geom_histogram(position="identity", 
                 binwidth=100, col="white")+ 
  theme_classic()+
  labs(title="Men - No Grad School")
#
#Create Men-GradEd DF
MenGradEd <- subset(SalaryData, 
                     gender=="man" &
                       GradEd=="Grad")
#Produce Men-GradEd histogram
ggplot(data=MenGradEd, 
       aes(x=Wk_salaryDollar))+ 
  geom_histogram(position="identity", 
                 binwidth=100, col="white")+ 
  theme_classic()+
  labs(title="Men - GradEd")
#ALTERNATIVE: Historgram by Group using facet_wrap
ggplot(data=SalaryData, 
       aes(x=Wk_salaryDollar))+ 
  geom_histogram(position="identity", 
                 binwidth=100, col="white")+ 
  theme_classic()+
  facet_wrap(~GradEd+gender)
#
###Boxplot by Cell----
ggplot(data=SalaryData, 
     aes(x=gender, y=Wk_salaryDollar,
         fill=GradEd)) +
  geom_boxplot(notch = FALSE, width=.3)+
  scale_fill_brewer(palette="Set1") +
  labs(title="Salary Boxplot", 
    subtitle="by Gender and Grad School Status",
    fill="Grad School Status",
    x="Gender", y="Weekly Salary ($)") + 
  theme_classic() + 
  theme(axis.title=element_text(size=12),
    plot.title=element_text(hjust=.5),
    plot.subtitle=element_text(hjust=.5))
#
##Performing Factorial ANOVA----
FacAOVsalary <- ezANOVA(
  data=SalaryData, 
  wid=ID, type=3, return_aov = TRUE,
  dv=Wk_salaryDollar, 
  between=c(gender, GradEd))
summary.aov(FacAOVsalary$aov)
FacAOVsalary$"Levene's Test for Homogeneity of Variance"
#
##Presenting Results----
###Results by cell
ciPercent <- 95
DescByCell <- SalaryData %>% group_by(gender, GradEd) %>% 
  summarize(N=n(),Mean=mean(Wk_salaryDollar),
            sd=sd(Wk_salaryDollar),se=sd/sqrt(N), 
            ci=se*(qt((ciPercent/100)/2+.5, N-1)),
            LL=round(Mean-ci, 3), 
            UL=round(Mean+ci, 3))
View(DescByCell)
#
#Plots: Bar Chart by Cell
ggplot(data=DescByCell, aes(x=gender,
      y=Mean, fill=GradEd)) +
  geom_bar(stat="identity", position="dodge")+
  geom_errorbar(aes(ymin=Mean-ci, ymax=Mean+ci),
      width=.1, position=position_dodge(width=.9))+
  scale_fill_brewer(palette="Set1") +
  labs(title="Weekly Salary", x="Gender",
      subtitle="by Gender & Grad School Status",
      fill="Grad School Status", y="Weekly Salary ($)") + 
  theme_classic() +
  theme(axis.title = element_text(size = 12),
      plot.title=element_text(hjust=.5),
      plot.subtitle=element_text(hjust=.5))
#
#Interaction Cat and Quant----
##Checking Assumptions----
#Scatterplot Salary and Age accounting for Grad School
ggplot(SalaryData, aes(x=age, 
    y=Wk_salaryDollar, color=GradEd)) +
  geom_point(size=1, alpha=.4) +
  theme_classic() + labs(y="Weekly Salary ($)") +
  geom_smooth(method=lm, aes(fill=GradEd))
#
##Performing Regression----
Sal_AgeGradEd <- lm(Wk_salaryDollar~
                    age*GradEd, 
                    data=SalaryData)
summary.lm(Sal_AgeGradEd)
#
#Interaction with Two Quantitative Variables----
##Visually Check Assumptions----
###3D scatterplot - rotates
plot3d(SalaryData$Wk_salaryDollar~
         SalaryData$age+
         SalaryData$height)
#
###Scatterplot matrix
pairs(SalaryData$Wk_salaryDollar~
        SalaryData$age+
        SalaryData$height, 
      upper.panel=NULL)
###Bivariate Scatterplots
ggplot(SalaryData, aes(x=height, 
    y=Wk_salaryDollar)) +
  geom_point(size=1, alpha=.4) +
  theme_classic() + geom_smooth(method=lm)
ggplot(SalaryData, aes(x=age, 
    y=Wk_salaryDollar)) +
  geom_point(size=1, alpha=.4) +
  theme_classic() + geom_smooth(method=lm)
ggplot(SalaryData, aes(x=height, 
    y=age)) +
  geom_point(size=1, alpha=.4) +
  theme_classic() + geom_smooth(method=lm)
#
##Regression----
Reg_Sal_AgeHt <- lm(
      Wk_salaryDollar~
      Age_cent*Ht_cent, 
      data=SalaryData)
summary.lm(Reg_Sal_AgeHt)
#
#Graphing quant interaction
plot_model(Reg_Sal_AgeHt,type="int", 
           mdrt.values="meansd")
