#CHAPTER 8: ANCOVA
#Installing and attaching packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("ggplot2", "cowplot", "ez", "car", 
          "dplyr", "emmeans")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Data----
SalaryData <- read.csv("Salary_data5.csv",
  header=TRUE, na.strings=c("NA", " ", ""))
View(SalaryData)
#
#Checking assumptions----
##Histograms for normality
HtHist <- ggplot(data=SalaryData, 
                 aes(x=height))+ 
  geom_histogram(position="identity", 
          binwidth=2, col="white")+ 
  theme_classic()
SalaryHist <- ggplot(data=SalaryData, 
                aes(x=Wk_salaryDollar))+ 
  geom_histogram(position="identity", 
          binwidth=100, col="white")+ 
  theme_classic()
###Plot histograms
plot_grid(HtHist, SalaryHist, 
      labels=c("A", "B"), label_size = 10)
#
##Scatterplot with markers for groups
ggplot(SalaryData, aes(x=height, 
        y=Wk_salaryDollar, shape=gender)) +
  geom_point(size=2, alpha=.2) +
  theme_classic() +
  geom_smooth(method=lm, aes(color=gender)) +
  scale_color_manual(values=c("blue", "red"))
#
#One-way ANOVA----
ez_Ht <- ezANOVA(data=SalaryData, 
                 dv=height, wid= ID, 
                 between=gender, type=3, 
                 detailed=TRUE, 
                 return_aov=TRUE)
ez_Ht$ANOVA
#
ez_Salary <- ezANOVA(data=SalaryData, 
                dv=Wk_salaryDollar, wid= ID, 
                between=gender, type=3, 
                detailed=TRUE, 
                return_aov=TRUE)
ez_Salary$ANOVA
ez_Salary$`Levene's Test for Homogeneity of Variance`
#
#ANCOVA----
#ANCOVA: Salary based on Gender and Height
Sal_GenHt <- aov(Wk_salaryDollar~
  height*gender, data=SalaryData)
Anova(Sal_GenHt, type=3)
#
#ANCOVA without interaction
Sal_GenHt_noInt <- aov(Wk_salaryDollar~
    gender+height, data=SalaryData)
Anova(Sal_GenHt_noInt, type=3)
#
#Presenting Results----
#Results by Gender: Unadjusted
ciPercent <- 95
DescByGender <- SalaryData %>% group_by(gender) %>% 
  summarize(N=n(),Mean=mean(Wk_salaryDollar),
            sd=sd(Wk_salaryDollar),se=sd/sqrt(N), 
            ci=se*(qt((ciPercent/100)/2+.5, N-1)),
            LL=round(Mean-ci, 3), 
            UL=round(Mean+ci, 3))
View(DescByGender)
#
#Adjusted means by gender accounting for height
emmeans(Sal_GenHt_noInt, "gender")
