#CHAPTER 9: WARNER Appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "ggplot2", "bda", "semPlot")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import WARNER Age, Wt, Blood pressure data----
AgeWtBp <- read.spss("Warner/ageweightbp.sav", 
                  to.data.frame=TRUE)
names(AgeWtBp)
View(AgeWtBp)
#
#Check Assumptions----
#Normality: Histograms
#Autogenerate breaks
break_Age <- hist(AgeWtBp$Age, breaks="Sturges", plot=FALSE)
break_Wt <- hist(AgeWtBp$Weight, breaks="Sturges", plot=FALSE)
break_SBP <- hist(AgeWtBp$SBP, breaks="Sturges", plot=FALSE)
#Histograms
ggplot(AgeWtBp, aes(x=Age))+
  geom_histogram(
    breaks=break_Age$breaks, col="white")
ggplot(AgeWtBp, aes(x=Weight))+
  geom_histogram(
    breaks=break_Wt$breaks, col="white")
ggplot(AgeWtBp, aes(x=SBP))+
  geom_histogram(
    breaks=break_SBP$breaks, col="white")
#
#Linearity: Scatterplots
ggplot(AgeWtBp, aes(x=Age,y=SBP))+
  geom_point()
ggplot(AgeWtBp, aes(x=Weight,y=SBP))+
  geom_point()
ggplot(AgeWtBp, aes(x=Age,y=Weight))+
  geom_point()
#
#Performing Mediation----
#Model 1: x1 ->y
Mod_x1y <- lm(SBP~Age, data=AgeWtBp)
summary.lm(Mod_x1y)
#
#Model 2: x1 -> x2
Mod_x1x2 <- lm(Weight~Age, 
              data=AgeWtBp)
summary.lm(Mod_x1x2)
#
#Model 3: x1+x2 -> y
Mod_x1x2y <- lm(SBP~Age+Weight, 
               data=AgeWtBp)
summary.lm(Mod_x1x2y)
#
#Mediation test
mediation.test(mv=AgeWtBp$Weight, 
               iv=AgeWtBp$Age, 
               dv=AgeWtBp$SBP)
#
#Presenting results----
hor <- c(-1, 0, 1)
vert <- c(-1, 0, -1)
Place <- matrix(c(hor, vert), ncol=2)
View(Place)
semPaths(Mod_x1x2+Mod_x1x2y, 
        whatLabels="par",
        edge.label.cex = 1.5,
        edge.color = "black",
        residuals=FALSE,
        intercepts=FALSE,
        sizeMan=12, 
        sizeMan2=7, 
        layout=Place)
