#CHAPTER 9: Mediation
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("ggplot2", "bda", "semPlot")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Disclosure and Satisfaction data----
RelSat_DF <- read.csv("Avo_Disc_RelSat.csv", 
                      header=TRUE, 
                      na.strings=c("NA", " ", ""))
names(RelSat_DF)
View(RelSat_DF)
#
#Check Assumptions----
##Normality and Univariate Outliers: Histograms----
###Autogenerate breaks
break_Avo <- hist(RelSat_DF$ECRRS_AVO, 
                breaks="Sturges", plot=FALSE)
break_Disclosure <- hist(RelSat_DF$Disclosure, 
                breaks="Sturges", plot=FALSE)
break_RelSat <- hist(RelSat_DF$RelSat, 
                breaks="Sturges", plot=FALSE)
###Histograms
ggplot(RelSat_DF, aes(x=ECRRS_AVO))+
  geom_histogram(
    breaks=break_Avo$breaks, col="white")
ggplot(RelSat_DF, aes(x=Disclosure))+
  geom_histogram(
    breaks=break_Disclosure$breaks, col="white")
ggplot(RelSat_DF, aes(x=RelSat))+
  geom_histogram(
    breaks=break_RelSat$breaks, col="white")
#
##Linearity and Bivariate Outliers: Scatterplots----
ggplot(RelSat_DF, aes(x=ECRRS_AVO,y=RelSat))+
  geom_point()
ggplot(RelSat_DF, aes(x=Disclosure,y=RelSat))+
  geom_point()
ggplot(RelSat_DF, aes(x=ECRRS_AVO,y=Disclosure))+
  geom_point()
#
#Performing Mediation----
#Model 1: x1 ->y
Mod_x1y <- lm(RelSat~ECRRS_AVO, 
              data=RelSat_DF)
summary.lm(Mod_x1y)
#
#Model 2: x1 -> x2
Mod_x1x2 <- lm(Disclosure~
                 ECRRS_AVO, 
               data=RelSat_DF)
summary.lm(Mod_x1x2)
#
#Model 3: x1+x2 -> y
Mod_x1x2y <- lm(RelSat~
          ECRRS_AVO+Disclosure, 
                data=RelSat_DF)
summary.lm(Mod_x1x2y)
#
#Mediation test
mediation.test(mv=RelSat_DF$Disclosure, 
               iv=RelSat_DF$ECRRS_AVO, 
               dv=RelSat_DF$RelSat)
#
#Presenting results----
hor <- c(-1, 0, 1)
vert <- c(-1, 0, -1)
Place <- matrix(c(hor, vert), ncol=2)
semPaths(Mod_x1x2+Mod_x1x2y, 
         whatLabels="par",
         edge.label.cex = 1.5,
         edge.color = "black",
         residuals=FALSE,
         intercepts=FALSE,
         sizeMan=12, 
         sizeMan2=7, 
         layout=Place)
