#CHAPTER 10: WARNER Appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "ggplot2", "biotools", "MASS", 
          "dplyr", "candisc", "car", "cowplot")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import WARNER talent data----
Talent_DF <- na.omit(read.spss("Warner/talent.sav", 
                     to.data.frame=TRUE))
names(Talent_DF)
View(Talent_DF)
#
#Check Assumptions----
#Normality and univariate outliers
ggplot(Talent_DF, aes(x=english, fill=cargroup))+
  geom_histogram(binwidth=4, col="white")
ggplot(Talent_DF, aes(x=reading, fill=cargroup))+
  geom_histogram(binwidth=4, col="white")
ggplot(Talent_DF, aes(x=mechanic, fill=cargroup))+
  geom_histogram(binwidth=4, col="white")
ggplot(Talent_DF, aes(x=abstract, fill=cargroup))+
  geom_histogram(binwidth=4, col="white")
ggplot(Talent_DF, aes(x=math, fill=cargroup))+
  geom_histogram(binwidth=4, col="white")
ggplot(Talent_DF, aes(x=office, fill=cargroup))+
  geom_histogram(binwidth=4, col="white")
#
#Linearity & Bivariate Outliers
#Perform for all pairs of predictors
ggplot(Talent_DF, 
       aes(x=english, y=reading, 
            color=cargroup))+
  geom_point()
#
#Create matrix with predictors
DA_matrix <- as.matrix(Talent_DF[c(-1,-2)])
View(DA_matrix)
#
pairs(DA_matrix, upper.panel=NULL)
#
#Box's M
BoxTest <- boxM(DA_matrix, 
        Talent_DF$cargroup)
BoxTest
BoxTest$logDet
round(cov2cor(BoxTest$pooled), 3)
#
#Disciminant Analysis----
DA_mod <- lda(cargroup~english+reading+
                mechanic+abstract+math+
                office, 
              data=Talent_DF)
#
DA_mod <- lda(cargroup~DA_matrix, 
              data=Talent_DF)
DA_mod
round(DA_mod$scaling, 3)
View(round(DA_mod$means, 2))
#Prior probabilities
round(DA_mod$prior, 3)
#
#Predict Values and Class
DA_pred <- predict(DA_mod)
#
#Data Frame with predicted values and class
DA_DF <- cbind.data.frame(Talent_DF, DA_pred$x, class=DA_pred$class)
View(DA_DF)
DescByGrp <- DA_DF %>% 
  group_by(cargroup) %>% 
  summarize(Engl=mean(english),
            Rdng=mean(reading),
            Mech=mean(mechanic),
            Abst=mean(abstract),
            Math=mean(math), 
            Off=mean(office), 
            LD1=mean(LD1), 
            LD2=mean(LD2))%>% 
  mutate_at(vars(-cargroup),as.numeric) %>% 
  mutate_at(vars(-cargroup), round, 2)
View(DescByGrp)
#
#Univariate ANOVAs
AOV_out <- aov(DA_matrix~
       Talent_DF$cargroup)
summary.aov(AOV_out)
sumAOV <- summary.aov(AOV_out)
View(sumAOV$` Response english`)
#
#Wilks Lambda
DA_manova <- manova(DA_matrix~
            Talent_DF$cargroup)
DA_wilks <- summary(DA_manova, 
                test="Wilks")
DA_wilks
#
CanOut <- candisc(DA_manova)
CanOut
#
#Summary of Canonical Descrim Fxn
#Eigenvalues
round(CanOut$eigenvalues[1:2], 3)
#Canonical Discrim Fxn: % of Var
round(CanOut$pct[1:2], 1)
#Canonical Corr
round(sqrt(CanOut$canrsq), 3)
#Wilks
Wilks(CanOut)
#
#Standardized Coefs
round(CanOut$coeffs.std, 3)
#
#Corr Predictors with Discrim Fxns
CanOut$structure[order(-abs(
  CanOut$structure[,1])),]
#
#Raw Score Coefs
round(CanOut$coeffs.raw, 3)
#
#Means on discriminant functions
round(CanOut$means, 3)
#
#ANOVA with Discriminant Functions
LD1aov <- aov(LD1~cargroup, 
              data=DA_DF)
LD2aov <- aov(LD2~cargroup, 
              data=DA_DF)
Anova(LD1aov, type=3)
Anova(LD2aov, type=3)
#
#Present Results----
#Create classification table
ClassTab <- table(DA_DF$cargroup, 
                  DA_DF$class)
print(ClassTab)
#Add percentages
ClassPercent <- round((prop.table(
  ClassTab, margin=1)*100), 1)
print(ClassPercent)
#
#Plot discriminant functions
PlotByPred <- ggplot(DA_DF, aes(LD1,LD2, color=class)) +
  geom_point()+
  theme(legend.position="none", 
        axis.title = element_text(size=8))
PlotByActual <- ggplot(DA_DF, aes(LD1, LD2, color=cargroup))+
  geom_point()+
  theme(legend.position="none", 
        axis.title = element_text(size=8))
Legen_WaitForIt_dary <- 
  get_legend(ggplot(DA_DF, 
        aes(LD1, LD2, color=cargroup))+
    geom_point()+
    theme(legend.position = "bottom",
      legend.background = element_blank(),
      legend.title=element_text(size=8), 
      legend.text=element_text(size=8)))
Plots <- plot_grid(PlotByPred, PlotByActual,
          labels=c("Pred", "Actual"),
          label_size=8, vjust=2.5)
plot_grid(Plots, Legen_WaitForIt_dary,
          align="v", ncol=1, axis="l",
          rel_heights = c(4, 1))
#
#Add Group Means
ggplot(DA_DF, aes(LD1, LD2, 
                  color=cargroup))+
  geom_point(alpha=.5)+
  geom_point(data=DescByGrp, size=4)+
  scale_color_brewer(palette="Set1")
