#CHAPTER 10: Discriminant Analysis
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("ggplot2", "biotools", "MASS", "dplyr", 
          "candisc", "car", "cowplot")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Predict Relationship Status data----
RelStatus_DF <- read.csv("PredRelStatus.csv", 
                      header=TRUE, 
                      na.strings=c("NA", " ", ""))
names(RelStatus_DF)
View(RelStatus_DF)
table(RelStatus_DF$currRomStat)
#
#Check Assumptions----
##Normality and univariate outliers----
ggplot(RelStatus_DF, aes(x=Happy, fill=currRomStat))+
  geom_histogram(binwidth=4, col="white")
ggplot(RelStatus_DF, aes(x=LifeSat, fill=currRomStat))+
  geom_histogram(binwidth=4, col="white")
ggplot(RelStatus_DF, aes(x=PosAff, fill=currRomStat))+
  geom_histogram(binwidth=4, col="white")
ggplot(RelStatus_DF, aes(x=NegAff, fill=currRomStat))+
  geom_histogram(binwidth=4, col="white")
ggplot(RelStatus_DF, aes(x=Conceal, fill=currRomStat))+
  geom_histogram(binwidth=4, col="white")
ggplot(RelStatus_DF, aes(x=Disclose, fill=currRomStat))+
  geom_histogram(binwidth=4, col="white")
ggplot(RelStatus_DF, aes(x=RelAuth, fill=currRomStat))+
  geom_histogram(binwidth=4, col="white")
#
##Linearity & Bivariate Outliers----
#Scatterplot
ggplot(RelStatus_DF,  aes(x=Happy, y=LifeSat, 
           color=currRomStat))+
  geom_point()
#
#Create matrix with predictors
DA_matrix <- as.matrix(RelStatus_DF[-1])
View(DA_matrix)
#Scatterplots for all pairs of predictors
pairs(DA_matrix, upper.panel=NULL)
#
#Box's M
BoxTest <- boxM(
  DA_matrix, 
  RelStatus_DF$currRomStat)
BoxTest
BoxTest$logDet
round(cov2cor(
  BoxTest$pooled), 3)
#
#Disciminant Analysis----
DA_mod <- lda(
  currRomStat~DA_matrix, 
  data=RelStatus_DF)
DA_mod
#Prior probabilities
round(DA_mod$prior, 3)
#Raw score discrim fxc coefs
round(DA_mod$scaling, 3)
#Group means
View(round(DA_mod$means, 2))
#
#Predict Values and Class
DA_pred <- predict(DA_mod)
#
#Data Frame with predicted values and class
DA_DF <- cbind.data.frame(RelStatus_DF, DA_pred$x, class=DA_pred$class)
View(DA_DF)
names(DA_DF)
DescByGrp <- DA_DF %>% 
  group_by(currRomStat) %>% 
  summarize(Happy=mean(Happy),
            LifeSat=mean(LifeSat),
            PosAff=mean(PosAff),
            NegAff=mean(NegAff),
            Conc=mean(Conceal),
            Disc=mean(Disclose),
            RelAuth=mean(RelAuth),
            LD1=mean(LD1), 
            LD2=mean(LD2))%>% 
  mutate_at(vars(-currRomStat),as.numeric) %>% 
  mutate_at(vars(-currRomStat), round, 2)
View(DescByGrp)
#
#Univariate ANOVAs
AOV_out <- aov(DA_matrix~
  RelStatus_DF$currRomStat)
summary.aov(AOV_out)
#
sumAOV <- summary.aov(AOV_out)
View(sumAOV$` Response Happy`)
#
#Wilks Lambda
DA_manova <- manova(DA_matrix~
      RelStatus_DF$currRomStat)
summary(DA_manova, test="Wilks")
#
CanOut <- candisc(DA_manova)
CanOut
#
#Summary of Canonical Descrim Fxn
#Eigenvalues
round(CanOut$eigenvalues[1:2], 3)
#Canonical Discrim Fxn: % of Var
round(CanOut$pct[1:2], 1)
#Canonical Corr
round(sqrt(CanOut$canrsq), 3)
#Wilks
Wilks(CanOut)
#
#Standardized Coefs
round(CanOut$coeffs.std, 3)
#
#Corr Predictors with Discrim Fxns
CanOut$structure[order(-abs(
  CanOut$structure[,1])),]
#
#Raw Score Coefs
round(CanOut$coeffs.raw, 3)
#
#Means on discriminant functions
round(CanOut$means, 3)
#
#ANOVA with Discriminant Functions
LD1aov <- aov(LD1~currRomStat, 
              data=DA_DF)
LD2aov <- aov(LD2~currRomStat, 
              data=DA_DF)
Anova(LD1aov, type=3)
Anova(LD2aov, type=3)
#
#Present Results----
#Create classification table
ClassTab <- table(
  DA_DF$currRomStat, 
  DA_DF$class)
print(ClassTab)
#Add percentages
ClassPercent <- round((
  prop.table(
  ClassTab, margin=1)*100), 1)
print(ClassPercent)
#
#Plot discriminant functions
PlotByPred <- ggplot(DA_DF, aes(LD1,LD2, color=class)) +
  geom_point()+
  theme(legend.position="none", 
        axis.title = element_text(size=8))+
  scale_color_manual(values=c("yellow1", "grey27", "limegreen"))
PlotByActual <- ggplot(DA_DF, aes(LD1, LD2, color=currRomStat))+
  geom_point()+
  theme(legend.position="none", 
        axis.title = element_text(size=8))+
  scale_color_manual(values=c("yellow1", "grey27", "limegreen"))
Legen_WaitForIt_dary <- 
  get_legend(ggplot(DA_DF, 
   aes(LD1, LD2, color=currRomStat))+
   geom_point()+
   theme(legend.position = "bottom",
    legend.background = element_blank(),
    legend.title=element_text(size=8), 
    legend.text=element_text(size=8))+
  scale_color_manual(values=c("yellow1", "grey27", "limegreen")))
Plots <- plot_grid(PlotByPred, PlotByActual,
           labels=c("Pred", "Actual"),
           label_size=8, vjust=2.5)
plot_grid(Plots, Legen_WaitForIt_dary,
    align="v", ncol=1, axis="l",
    rel_heights = c(4, 1))
#
#Add Group Means
ggplot(DA_DF, aes(LD1, LD2, 
                  color=currRomStat))+
  geom_point(alpha=.4)+
  geom_point(data=DescByGrp, size=4)+
  scale_color_manual(values=
    c("yellow1", "grey27", "limegreen"))
