#CHAPTER 11: WARNER Appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "MVN", "mvnormtest", "ggplot2", "biotools", 
          "MASS", "dplyr", "candisc", "car", "cowplot")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import WARNER talent data----
Talent_DF <- na.omit(read.spss("Warner/talent.sav", 
                     to.data.frame=TRUE))
names(Talent_DF)
View(Talent_DF)
#
#Check Assumptions----
#Create Matrix with Dep. Vars.
#Note: This is same as DA_matrix from Ch. 10
Dep_matrix <- as.matrix(Talent_DF[c(-1,-2)])
#
#Plot Multivariate Normality
mvn(Dep_matrix, multivariatePlot="qq")
#
#Create DF with Dep. Vars. and grouping var
Mod_Vars <- as.data.frame(Talent_DF[-2])
#
#Plot multivariate normality by group
mvn(Mod_Vars,  subset="cargroup",
    multivariatePlot = "qq")
#
NormTest <- mvn(Dep_matrix, 
              mvnTest="royston", 
              univariateTest="Lillie")
NormTest$multivariateNormality
#
NormTestByGrp <- mvn(Mod_Vars,
                subset="cargroup",
                mvnTest="royston",
                univariateTest="Lillie")
NormTestByGrp$multivariateNormality
#
mshapiro.test(t(Dep_matrix))
#
#Univariate Normality
View(NormTest$univariateNormality)
mvn(Dep_matrix, 
    univariatePlot="histogram")
mvn(Dep_matrix, 
    univariatePlot="qqplot")
#
#Descriptive Statistics
View(NormTest$Descriptives)
View(NormTestByGrp$Descriptives$business)
#
#MANOVA----
ManovaOut <- manova(Dep_matrix~
                Talent_DF$cargroup)
Manova(ManovaOut, type=3)
Manova(ManovaOut, type=3, 
       test.statistic="Wilks")
Manova(ManovaOut, type=3, 
       test.statistic="Hotelling")
Manova(ManovaOut, type=3, 
       test.statistic="Roy")
#
#Follow-up ANOVAs (Type I SS)
summary.aov(ManovaOut)
#
#Follow-up ANOVAs (Type III SS)
eng_aov <- aov(english~cargroup, 
               data=Talent_DF)
Anova(eng_aov, type=3)
TukeyHSD(eng_aov)
#
read_aov <- aov(reading~cargroup, 
                data=Talent_DF)
Anova(read_aov, type=3)
TukeyHSD(read_aov)
#
mech_aov <- aov(mechanic~cargroup, 
                data=Talent_DF)
Anova(mech_aov, type=3)
TukeyHSD(mech_aov)
#
abst_aov <- aov(abstract~cargroup, data=Talent_DF)
Anova(abst_aov, type=3)
TukeyHSD(abst_aov)
#
math_aov <- aov(math~cargroup, data=Talent_DF)
Anova(math_aov, type=3)
TukeyHSD(math_aov)
#
office_aov <- aov(office~cargroup, data=Talent_DF)
Anova(office_aov, type=3)
TukeyHSD(office_aov)
#
#
#Factorial MANOVA----
FacTab <- table(Talent_DF$gender, 
                Talent_DF$cargroup)
FacTab
round(prop.table(FacTab, 1)*100, 1)
#
FacManovaOut <- manova(Dep_matrix~
      Talent_DF$gender*Talent_DF$cargroup)
Manova(FacManovaOut, type=3)
Manova(FacManovaOut, type=3, 
       test.statistic="Wilks")
Manova(FacManovaOut, type=3, 
       test.statistic="Hotelling")
Manova(FacManovaOut, type=3, 
       test.statistic="Roy")
#
#Follow-up Univariate ANOVA
math_aov <- aov(math~cargroup, 
      data=Talent_DF)
Anova(math_aov, type=3)
office_aov <- aov(office~cargroup,
      data=Talent_DF)
Anova(office_aov, type=3)
#
#Descriptives
DescByGrp <- Talent_DF %>% 
  group_by(cargroup, gender) %>% 
  summarize(Engl=mean(english),
            EnglSD=sd(english),
            Rdng=mean(reading),
            RdngSD=sd(reading),
            Mech=mean(mechanic),
            MechSD=sd(mechanic),
            Abst=mean(abstract),
            AbstSD=sd(abstract),
            Math=mean(math), 
            MathSD=sd(math),
            Off=mean(office),
            OffSD=sd(office))%>% 
  mutate_at(vars(c(-cargroup, -gender)),as.numeric) %>% 
  mutate_at(vars(c(-cargroup, -gender)), round, 2)
View(DescByGrp)
#
#Univariate ANOVAs for gender
AOV_out <- aov(Dep_matrix~
      Talent_DF$gender)
summary.aov(AOV_out)
#
#Follow-up Discrim Analysis
DA_gender <- manova(Dep_matrix~
                    gender,
           data=Talent_DF)
CanOut <- candisc(DA_gender)
CanOut
#
#Canonical Corr
round(sqrt(CanOut$canrsq), 3)
#
#Standardized Coefs
round(CanOut$coeffs.std, 3)
#
#Means on discriminant functions
round(CanOut$means, 3)
#
#Results for men
DA_menDF <- subset(Talent_DF[which(Talent_DF$gender=="male"),]) 
View(DA_menDF)
DA_carMen <- manova(
        cbind(english, reading, 
              mechanic, abstract, 
              math, office)
        ~cargroup,
        data=DA_menDF)
CanOut_carMen <- candisc(DA_carMen)
CanOut_carMen
#
#Results for women
DA_womenDF <- subset(Talent_DF[which(Talent_DF$gender=="female"),])
View(DA_womenDF)
DA_carWomen <- manova(
        cbind(english, reading, 
              mechanic, abstract, 
              math, office)
        ~cargroup,
        data=DA_womenDF)
CanOut_carWomen <- candisc(DA_carWomen)
CanOut_carWomen
