#CHAPTER 11: MANOVA
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("MVN", "mvnormtest", "ggplot2", "biotools", "MASS",
          "dplyr", "candisc", "car", "cowplot")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Relationship Status and Gender data----
RelStat_Gen_DF <- read.csv("RelStatus_Gender.csv", 
                         header=TRUE, 
                         na.strings=c("NA", " ", ""))
names(RelStat_Gen_DF)
View(RelStat_Gen_DF)
#
#Check Assumptions----
##Plot Multivariate Normality----
mvn(Dep_matrix, 
    multivariatePlot="qq")
#
#Create Matrix with Dep. Vars.
#Note: This is same as DA_matrix from Ch. 10
Dep_matrix <- as.matrix(RelStat_Gen_DF[c(-1,-2)])
View(Dep_matrix)
#
mvnObj <- mvn(
  data=RelStat_Gen_DF[c(-1,-2)],
    mvnTest="royston",
    univariateTest = "Lillie",
    multivariatePlot = "qq",
    multivariateOutlierMethod = "adj",
    showOutliers = TRUE,
    showNewData = TRUE)
OutlierRm <- data.frame(mvnObj$newData)
View(OutlierRm)
mvnObj$multivariateNormality
mvnObj$univariateNormality

#
##Plot multivariate normality by group----
#Create DF with Dep. Vars. and grouping var
Mod_Vars <- as.data.frame(
  RelStat_Gen_DF[-1])
#
mvn(Mod_Vars,  subset="currRomStat",
    multivariatePlot = "qq")
#
NormTest <- mvn(Dep_matrix, 
                mvnTest="royston", 
                univariateTest="Lillie")
NormTest$multivariateNormality
#Univariate Normality
View(NormTest$univariateNormality)
#Normality by Group
NormTestByGrp <- mvn(Mod_Vars,
               subset="currRomStat",
               mvnTest="royston",
               univariateTest="Lillie")
NormTestByGrp$multivariateNormality
#
#Plot univariate histograms & QQ plots
mvn(Dep_matrix[,1:2], 
  univariatePlot="histogram")
mvn(Dep_matrix[,1:2], 
  univariatePlot="qqplot")
#
#Descriptive Statistics
View(NormTest$Descriptives)
View(NormTestByGrp$Descriptives$`No Curr`)
#
#MANOVA----
ManovaOut <- manova(Dep_matrix~
    RelStat_Gen_DF$currRomStat)
Manova(ManovaOut, type=3)
Manova(ManovaOut, type=3, 
    test.statistic="Wilks")
Manova(ManovaOut, type=3, 
    test.statistic="Hotelling")
Manova(ManovaOut, type=3, 
    test.statistic="Roy")
#
#Follow-up ANOVAs (Type I SS)
summary.aov(ManovaOut)
#
#Follow-up ANOVAs (Type III SS)
Happy_aov <- aov(
  Happy~currRomStat, 
  data=RelStat_Gen_DF)
Anova(Happy_aov, type=3)
TukeyHSD(Happy_aov)
#
LifeSat_aov <- aov(
  LifeSat~currRomStat, 
  data=RelStat_Gen_DF)
Anova(LifeSat_aov, type=3)
TukeyHSD(LifeSat_aov)
#
PosAff_aov <- aov(PosAff~currRomStat, 
                  data=RelStat_Gen_DF)
Anova(PosAff_aov, type=3)
TukeyHSD(PosAff_aov)
#
NegAff_aov <- aov(NegAff~currRomStat, 
                data=RelStat_Gen_DF)
Anova(NegAff_aov, type=3)
TukeyHSD(NegAff_aov)
#
Conc_aov <- aov(Conceal~currRomStat, 
            data=RelStat_Gen_DF)
Anova(Conc_aov, type=3)
TukeyHSD(Conc_aov)
#
Disc_aov <- aov(Disclose~currRomStat, 
                  data=RelStat_Gen_DF)
Anova(Disc_aov, type=3)
TukeyHSD(Disc_aov)
#
Auth_aov <- aov(RelAuth~currRomStat, 
                data=RelStat_Gen_DF)
Anova(Auth_aov, type=3)
TukeyHSD(Auth_aov)
#
#
#Factorial MANOVA----
FacTab <- table(RelStat_Gen_DF$Gender, 
        RelStat_Gen_DF$currRomStat)
FacTab
round(prop.table(FacTab, 1)*100, 1)
#
FacManovaOut <- manova(Dep_matrix~
        Gender*currRomStat, 
        data=RelStat_Gen_DF)
Manova(FacManovaOut, type=3)
Manova(FacManovaOut, type=3, 
     test.statistic="Wilks")
Manova(FacManovaOut, type=3, 
     test.statistic="Hotelling")
Manova(FacManovaOut, type=3, 
       test.statistic="Roy")
#
##Follow-up Univariate ANOVA----
Happy_aov <- aov(Happy~Gender, 
            data=RelStat_Gen_DF)
Anova(Happy_aov, type=3)
Disc_aov <- aov(Disclose~Gender, 
            data=RelStat_Gen_DF)
Anova(Disc_aov, type=3)
#
#Descriptives
MeanByGrp <- RelStat_Gen_DF %>% 
  group_by(currRomStat, Gender) %>% 
  summarize(Happ=mean(Happy),
            LifeSat=mean(LifeSat),
            PosAff=mean(PosAff),
            NegAff=mean(NegAff),
            Conc=mean(Conceal), 
            Disc=mean(Disclose),
            Auth=mean(RelAuth))%>% 
  mutate_at(vars(c(-currRomStat, -Gender)),as.numeric) %>% 
  mutate_at(vars(c(-currRomStat, -Gender)), round, 2)
View(MeanByGrp)
#
SDbyGrp <- RelStat_Gen_DF %>% 
  group_by(currRomStat, Gender) %>% 
  summarize(Happ=sd(Happy),
            LifeSat=sd(LifeSat),
            PosAff=sd(PosAff),
            NegAff=sd(NegAff),
            Conc=sd(Conceal), 
            Disc=sd(Disclose),
            Auth=sd(RelAuth)) %>% 
  mutate_at(vars(c(-currRomStat, -Gender)),as.numeric) %>% 
  mutate_at(vars(c(-currRomStat, -Gender)), round, 2)
View(SDbyGrp)
#
##Follow-up Discrim Analysis----
DA_Gender <- manova(Dep_matrix~
                    Gender,
            data=RelStat_Gen_DF)
CanOut <- candisc(DA_Gender)
CanOut
#
#Canonical Corr
round(sqrt(CanOut$canrsq), 3)
#
#Standardized Coefs
round(CanOut$coeffs.std, 3)
#
#Means on discriminant functions
round(CanOut$means, 3)
#
#Results for men
DA_menDF <- subset(RelStat_Gen_DF
  [which(RelStat_Gen_DF$Gender
         =="Male"),]) 
DA_RelStat_Men <- manova(
  cbind(Happy, LifeSat, PosAff, 
    NegAff, Conceal, Disclose, 
    RelAuth) ~ currRomStat,
  data=DA_menDF)
CanOut_RelStat_Men <- candisc(
  DA_RelStat_Men)
CanOut_RelStat_Men
#
#Results for women
DA_womenDF <- subset(RelStat_Gen_DF[which(RelStat_Gen_DF$Gender=="Female"),])
View(DA_womenDF)
DA_RelStat_Women <- manova(
  cbind(Happy, LifeSat, PosAff, NegAff,
        Conceal, Disclose, RelAuth)
  ~currRomStat,
  data=DA_womenDF)
CanOut_RelStat_Women <- candisc(DA_RelStat_Women)
CanOut_RelStat_Women