#CHAPTER 12: WARNER Appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "FactoMineR", "psych", "ggplot2")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import WARNER Bem Sex Role data----
EFA_DF <- na.omit(read.spss("Warner/bsri_12.sav", 
                               to.data.frame=TRUE))
names(EFA_DF)
View(EFA_DF)
#
#Item correlations
View(round(cor(EFA_DF), 3))
#
#Scatterplots for 3 items
examp1 <- as.data.frame(cbind(
        EFA_DF[,c(1,2,4)]))
pairs(examp1, upper.panel=NULL)
#
#Correlations between 3 items
round(cor(examp1), 3)
#
#Performing PCA
PCA_FacMine <- PCA(examp1)
round(PCA_FacMine$eig, 3)
round(PCA_FacMine$var$cor, 3)
#
#PCA: Retain 1 Component
PCA_1Comp <- PCA(examp1, ncp=1, graph=FALSE)
round(PCA_1Comp$eig, 3)
round(PCA_1Comp$var$cor, 3)
#
#Principal Axis Factoring
PAF <- fa(EFA_DF, nfactors=2, fm="pa", rotate="none")
#Save Initial communalities
IntComm <- round(smc(EFA_DF),3)
#Save communalities based on retained factors
ExtComm <- round(PAF$communality,3)
CommDF <- data.frame(IntComm,ExtComm)
#View communalities
View(CommDF)
#
PAF$Vaccounted
#
scree(EFA_DF, factors=TRUE,
      pc=FALSE)
#
EigVals <- as.data.frame(PAF$e.values)
View(EigVals)
EigVals$Facs <- row.names(EigVals)
ggplot(EigVals, aes(x=Facs, 
    y=PAF$e.values, group=1)) +
  geom_line()+geom_point()
#
fa.sort(PAF$loadings)
#
plot.psych(PAF,
  labels=c(substr(colnames(EFA_DF),1,4)),
  pos=c(1,4,4,1,4,4,2,4,2),
  xlim=c(-.1, 1.2), 
  ylim=c(-.8,.8), 
  xlab="Factor 1", 
  ylab="Factor 2")
#
#PAF with rotation
PAF_rot <- fa(EFA_DF, nfactors=2, 
    fm="pa", rotate="varimax")
#
round(PAF_rot$Vaccounted, 3)
#
fa.sort(PAF_rot$loadings)
#
plot.psych(PAF_rot,
           labels=c(substr(colnames(EFA_DF),1,4)),
           pos=c(1,4,4,4,4,4,3,2,3),
           xlim=c(-.5, 1.2), 
           ylim=c(-.8,.8), 
           xlab="Factor 1", 
           ylab="Factor 2")
#
round(PAF_rot$weights, 3)
