#CHAPTER 12: Exploratory Factor Analysis
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("FactoMineR", "psych", "ggplot2")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import EFA Items data----
EFA_DF <- read.csv("EFA_items.csv", 
            header=TRUE, 
            na.strings=c("NA", " ", ""))
names(EFA_DF)
View(EFA_DF)
#
#Item correlations
View(round(cor(EFA_DF), 3))
#
#Performing PCA----
PCA_out <- PCA(EFA_DF)
round(PCA_out$eig[,1:2],3)
round(PCA_out$var$cor, 3)
#
#PCA: Retain 1 Component
PCA_1Comp <- PCA(EFA_DF, ncp=1, graph=FALSE)
round(PCA_1Comp$eig[,1:2], 3)
View(round(PCA_1Comp$var$cor, 3))
#
#Principal Axis Factoring---- 
PAF <- fa(EFA_DF, nfactors=2, fm="pa", rotate="none")
#Save Initial communalities
IntComm <- round(smc(EFA_DF),3)
#Save communalities based on retained factors
ExtComm <- round(PAF$communality,3)
CommDF <- data.frame(IntComm,ExtComm)
#View communalities
View(CommDF)
#
PAF$Vaccounted
#
scree(EFA_DF, factors=TRUE,
      pc=FALSE)
#Plot initial Eigenvalues
EigVals <- as.data.frame(
            PAF$e.values)
View(EigVals)
EigVals$Facs <- row.names(EigVals)
ggplot(EigVals, aes(x=Facs, 
  y=PAF$e.values, group=1)) +
  geom_line()+geom_point()
#
fa.sort(PAF$loadings)
#
plot.psych(PAF,
     labels=c(colnames(EFA_DF)),
     pos=c(4,1,2,4,3,2,4,3,2),
     xlim=c(-.6, 1.1),
     ylim=c(-.7, .6),
     xlab="Factor 1", 
     ylab="Factor 2", 
     cex=.7, 
     cex.main=.8, 
     cex.axis=.8, 
     cex.lab=.8)
#
#PAF with rotation
PAF_rot <- fa(EFA_DF, nfactors=2, 
              fm="pa", rotate="varimax")
#
round(PAF_rot$Vaccounted, 3)
#
fa.sort(PAF_rot$loadings)
#Plot factor loadings
plot.psych(PAF_rot,
      labels=c(colnames(EFA_DF)),
      pos=c(3,2,1,4,4,2,3,1,3),
      xlim=c(-.5, 1.1), 
      ylim=c(-.8, 1.1), 
      xlab="Factor 1", 
      ylab="Factor 2", 
      cex=.8, cex.main=.8, 
      cex.lab=.8, cex.axis=.8)
#Factor coefficients
round(PAF_rot$weights, 3)
