#CHAPTER 14: WARNER appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "additivityTests", "reshape2", 
          "ez", "multcomp", "dplyr", "ggplot2", "car")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Data
Repeat_HR <- read.spss(
        "Warner/hrbpsocialstress.sav",
        to.data.frame=TRUE)
View(Repeat_HR)
#
#Save matrix with HR T1 - T5
TimeHR <- as.matrix(subset.data.frame(
  Repeat_HR, select=c("hr1", "hr2","hr3",
                      "hr4","hr5")))
#Correlations
round(cor(TimeHR), 3)
#
#Tukey Additivity test
tukey.test(TimeHR)
#
#Perform repeated-measures ANOVA----
#Re-shape data into long format
LongHR <- melt(Repeat_HR, id.vars="subn", 
        measure.vars=c("hr1", "hr2", "hr3", 
                "hr4", "hr5"))
View(LongHR)
#Perform ANOVA
HRrptAOV <- ezANOVA(data=LongHR, 
      dv=value, wid=subn, 
      within=.(variable), type=3, 
      detailed=TRUE, return_aov=TRUE)
HRrptAOV$`Mauchly's Test for Sphericity`
HRrptAOV$ANOVA
HRrptAOV$`Sphericity Corrections`
#
#Post-hoc tests 
post <- pairwise.t.test(
  LongHR$value, LongHR$variable, 
  paired=TRUE, p.adj = "holm")
View(round(post$p.value, 3))
View(format.pval(post$p.value, eps=.001,
                 digits=3))
#
#Summarize hr by time
model.tables(HRrptAOV$aov, "means")
#
HR_summ<- LongHR %>% group_by(variable) %>% 
  summarize(N=n(),
            mean=mean(value),
            sd=sd(value),
            se=sd/sqrt(N), ci=se*(qt(.975, N-1)),
            LL=mean-ci, UL=mean+ci)
View(HR_summ)
#
#Visualize HR across time
ggplot(HR_summ, aes(x=variable, y=mean))+
  geom_point()+
  geom_errorbar(width=.4, 
          aes(ymin=LL, ymax=UL))
#
#Follow-up----
LongHR <- melt(Repeat_HR, id.vars="subn", 
               measure.vars=c("hr1", "hr2", "hr3", 
                              "hr4", "hr5"))
LongSYS <- melt(Repeat_HR, id.vars="subn", 
               measure.vars=c("sys1", "sys2", "sys3", 
                              "sys4", "sys5"))
LongDIA <- melt(Repeat_HR, id.vars="subn", 
               measure.vars=c("dia1", "dia2", "dia3", 
                              "dia4", "dia5"))
LongCombo <- data.frame(LongHR[,1:2],HR=LongHR[,3],
                        SYS=LongSYS[,3],DIA=LongDIA[,3])
View(LongCombo)
#
HRrptAOV <- ezANOVA(data=LongCombo, dv=HR,
        wid=subn, within=.(variable), 
        type=3, detailed=TRUE, return_aov=TRUE)
HRrptAOV$ANOVA
#Post-hoc tests 
postHR <- pairwise.t.test(
  LongCombo$HR, LongCombo$variable, 
  paired=TRUE, p.adj = "holm")
View(round(postHR$p.value, 3))
#
SYSrptAOV <- ezANOVA(data=LongCombo, dv=SYS,
                    wid=subn, within=.(variable), 
                    type=3, detailed=TRUE, return_aov=TRUE)
SYSrptAOV$ANOVA
#Post-hoc tests 
postSYS <- pairwise.t.test(
  LongCombo$SYS, LongCombo$variable, 
  paired=TRUE, p.adj = "holm")
View(round(postSYS$p.value, 3))
#
DIArptAOV <- ezANOVA(data=LongCombo, dv=DIA,
                    wid=subn, within=.(variable), 
                    type=3, detailed=TRUE, return_aov=TRUE)
DIArptAOV$ANOVA
#Post-hoc tests 
postHR <- pairwise.t.test(
  LongCombo$DIA, LongCombo$variable, 
  paired=TRUE, p.adj = "holm")
View(round(postHR$p.value, 3))
#
#Mixed Models----
modWideHR <- lm(
  cbind(hr1,hr2,hr3,hr4,hr5)~sex,
        data=Repeat_HR)
idata2 <- data.frame(time=ordered(1:5))
modSum <- summary(Anova(modWideHR, 
    idata=idata2, idesign=~time), 
    multivariate=TRUE, univariate=FALSE)
modSum$multivariate.tests$`time`
modSum$multivariate.tests$`sex:time`
modSum$multivariate.tests$`sex`
#
#Mixed Model with Well-Being Intervention----
#Import Data
WellBeing_DF <- read.spss(
  "Warner/wellbeinginterventions.sav",
                  to.data.frame=TRUE)
names(WellBeing_DF)
WellBeing_DF$subn <- factor(rownames(WellBeing_DF))
#Reshape data
LongWBwSexInt <- melt(WellBeing_DF, id.vars=c("subn","Sex","Intervention"), 
                   measure.vars=c("WB1", "WB2", "WB3"))
colnames(LongWBwSexInt)[colnames(LongWBwSexInt)=="variable"] <- "Time"
View(LongWBwSexInt)
#
#Run Mixed ANOVA
WBintAOV <- ezANOVA(data=LongWBwSexInt, 
    dv=value, wid=subn, 
    between = Intervention,
    within=Time, type=3,
    detailed=TRUE, return_aov=TRUE)
WBintAOV$ANOVA
WBintAOV$`Sphericity Corrections`
#
#Follow-up with Split Data----
LongWB_cont <- subset(LongWBwSexInt[which(
  LongWBwSexInt$Intervention=="control"), ])
LongWB_relax <- subset(LongWBwSexInt[which(
  LongWBwSexInt$Intervention=="relaxation"), ])
LongWB_meditation <- subset(LongWBwSexInt[which(
  LongWBwSexInt$Intervention=="meditation"),])
#
ContAOV <- ezANOVA(data=LongWB_cont, dv=value,
              wid=subn,
              within=Time, type=3,
              detailed=TRUE, return_aov=TRUE)
ContAOV$ANOVA
ContAOV$`Sphericity Corrections`
#
relaxAOV <- ezANOVA(data=LongWB_relax, dv=value,
                   wid=subn,
                   within=Time, type=3,
                   detailed=TRUE, return_aov=TRUE)
relaxAOV$ANOVA
relaxAOV$`Sphericity Corrections`
#
meditateAOV <- ezANOVA(data=LongWB_meditation, dv=value,
                    wid=subn,
                    within=Time, type=3,
                    detailed=TRUE, return_aov=TRUE)
meditateAOV$ANOVA
meditateAOV$`Sphericity Corrections`
#
#Comparisons across intervention groups at 3 time points----
WBintAOV_WB1 <- ezANOVA(data=WellBeing_DF, dv=WB1,
          wid=subn, between=Intervention, type=3,
          detailed=TRUE, return_aov=TRUE)
WBintAOV_WB1$ANOVA
#
WBintAOV_WB2 <- ezANOVA(data=WellBeing_DF, dv=WB2,
          wid=subn, between=Intervention, type=3,
          detailed=TRUE, return_aov=TRUE)
WBintAOV_WB2$ANOVA
#
WBintAOV_WB3 <- ezANOVA(data=WellBeing_DF, dv=WB3,
          wid=subn, between=Intervention, type=3,
          detailed=TRUE, return_aov=TRUE)
WBintAOV_WB3$ANOVA
#
#Order Effects----
#Import Data
Drinks_DF <- na.omit(read.spss("Warner/drinks.sav",
                       to.data.frame=TRUE))
names(Drinks_DF)
View(Drinks_DF)
Drinks_DF$subn <- rownames(Drinks_DF)
#
#Reshape Data
LongDrinks <- melt(Drinks_DF, 
      id.vars=c("subn","order","RUMAFTERGIN"), 
      measure.vars=c("gin","vodka","rum"))
colnames(LongDrinks)[colnames(LongDrinks)
              =="variable"] <- "AlcoholType"
View(LongDrinks)
LongDrinks$order <- factor(LongDrinks$order)
LongDrinks$subn <- factor(LongDrinks$subn)
#
DrinksAOV <- ezANOVA(data=LongDrinks,dv=value,
        wid=subn, between=order,
        within= AlcoholType, type=3,
        detailed=TRUE, return_aov=TRUE)
DrinksAOV$ANOVA
#
model.tables(DrinksAOV$aov, "means")
#
#Friend vs Actor----
#Import Data
FriendVsAct_DF <- na.omit(read.spss("Warner/actorvsfriend.sav",
                               to.data.frame=TRUE))
names(FriendVsAct_DF)
View(FriendVsAct_DF)
FriendVsAct_DF$subn <- rownames(FriendVsAct_DF)
#
#Reshape Data
LongFriend <- melt(FriendVsAct_DF, 
   id.vars=c("subn","order"), 
   measure.vars=c("friendrating","actressrating"))
colnames(LongFriend)[colnames(LongFriend)
              =="variable"] <- "PersonRated"
View(LongFriend)
LongFriend$order <- factor(LongFriend$order)
LongFriend$subn <- factor(LongFriend$subn)
#
FriendActorAOV <- ezANOVA(data=LongFriend, 
      dv=value, wid=subn, between=order,
      within= PersonRated, type=3,
      detailed=TRUE, return_aov=TRUE)
FriendActorAOV$ANOVA
#Visualize Results
ggplot(LongFriend, aes(x=PersonRated, 
                      y=value, fill=order))+
  geom_bar(stat="summary", 
    position="dodge", fun.y="mean", 
    col="white")+
  scale_fill_brewer(palette="Set1")+
  theme_classic()