#CHAPTER 14: Repeated Measures Cont
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("psych", "additivityTests", "reshape2", 
          "ez", "multcomp", "dplyr", "ggplot2", "car")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import salary data
Repeat_Salary <- read.csv(
  "Salary_T2T3.csv", 
  header=TRUE, 
  na.strings=c("NA", " ", ""))
View(Repeat_Salary)
Repeat_Salary$ID <- factor(
  Repeat_Salary$ID)
#
#Save matrix with salary T1 to T3
TimeSal <- as.matrix(
  subset.data.frame(
  Repeat_Salary, 
  select=c("SalaryTime1", 
        "SalaryTime2",
        "SalaryTime3")))
#Correlations
round(cor(TimeSal), 3)
#
#Tukey Additivity test
library(additivityTests)
tukey.test(TimeSal)
#
#Perform repeated-measures ANOVA----
#Re-shape data into long format
library(reshape2)
LongSal <- melt(Repeat_Salary, id.vars=c("ID","gender"), 
        measure.vars=c("SalaryTime1", 
                       "SalaryTime2", 
                       "SalaryTime3"))
colnames(LongSal)[colnames(LongSal)
       =="variable"] <- "Time"
View(LongSal)
#
#Perform ANOVA
library(ez)
SalrptAOV <- ezANOVA(data=LongSal, 
    dv=value, wid=ID, 
    within=Time, type=2, 
    detailed=TRUE, return_aov=TRUE)
SalrptAOV$`Mauchly's Test for Sphericity`
SalrptAOV$ANOVA
SalrptAOV$`Sphericity Corrections`
#
#Follow-up analyses
SalaryAOV <- aov(value~Time+ID, 
                 data=LongSal)
library(multcomp)
modAOVsalary <- glht(SalaryAOV, 
  linfct=mcp(Time="Tukey"), 
  test=adjusted(type="bonferroni"))
print(summary(modAOVsalary), 
      digits=3)
confint(modAOVsalary)
#
#Presenting Results----
#Summarize salary by time
model.tables(SalrptAOV$aov, "means")
#
library(dplyr)
Sal_summ<- LongSal %>% group_by(Time) %>% 
  summarize(N=n(),
            mean=mean(value),
            sd=sd(value),
            se=sd/sqrt(N), ci=se*(qt(.975, N-1)),
            LL=mean-ci, UL=mean+ci)
View(Sal_summ)
#
#Visualize Salary across time
library(ggplot2)
ggplot(Sal_summ, aes(x=Time, y=mean))+
  geom_errorbar(aes(ymin=LL, 
          ymax=UL, width=.1))+
  geom_point(size=2) + 
  theme_classic()+
  labs(title="Weekly Salary", 
        subtitle="with 95% CI", 
        y="Salary ($)")+
  theme(axis.ticks.x=element_blank(),
    plot.title=element_text(hjust=.5),
    plot.subtitle=element_text(hjust=.5))
#
#Salary By Gender - Mixed ANOVA
library(ez)
SalGenderAOV <- ezANOVA(data=LongSal, 
      dv=value, wid=ID, within=Time, 
      between=gender, type=3, 
      detailed=TRUE, return_aov=TRUE)
print(SalGenderAOV$ANOVA[2:4,c(1:3,6:7)], 
      digits=4)
SalGenderAOV$`Mauchly's Test for Sphericity`
SalGenderAOV$`Sphericity Corrections`
#
View(Repeat_Salary)
modWideSalary <- lm(
  cbind(SalaryTime1,SalaryTime2, SalaryTime3)~gender,
  data=Repeat_Salary)
idata2 <- data.frame(time=ordered(1:3))
library(car)
modSum <- summary(Anova(modWideSalary, 
      idata=idata2, idesign=~time), 
      multivariate=TRUE, univariate=TRUE)
modSum$multivariate.tests$`gender:time`
print(modSum$univariate.tests
      [2:4,c(2,4,5,6)], digits=4)
modSum$multivariate.tests$gender
modSum$multivariate.tests$time
