#CHAPTER 15: WARNER Appendix
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("foreign", "lavaan", "semPlot",
          "ggplot2", "bda", "nonnest2")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import WARNER Age, Wt, Blood pressure data----
AgeWtBp <- read.spss(
    "Warner/ageweightbp.sav", 
      to.data.frame=TRUE)
names(AgeWtBp)
View(AgeWtBp)
#
#Model 1 - Mediation---
RegMod <- 'SBP~Age+Weight
            Weight~Age'
RegSEM <- sem(RegMod, data=AgeWtBp)
summary(RegSEM, rsq=TRUE)
semPaths(RegSEM)
#
MedMod <- 'SBP~c*Age
  Weight~a*Age
  SBP~b*Weight
  indirect:=a*b
  total:=c+(a*b)'
MedSEM <- sem(MedMod, data=AgeWtBp)
#Visualize Model
semPaths(MedSEM)
#Model Summary and Estimates
summary(MedSEM, rsq=TRUE)
parameterEstimates(MedSEM)
#Standardized estimates
parameterEstimates(MedSEM, standardized = TRUE)
standardizedSolution(MedSEM)
#
#Bootstrapped estimates
MedSEMboot <- sem(MedMod, data=AgeWtBp, se="boot")
summary(MedSEMboot, rsq=TRUE)
standardizedSolution(MedSEMboot)
#
#Correct order 
#(Left to Right; Predictor to Outcome)
hor <- c(1, 0, -1)
vert <- c(-1, 0, -1)
Place <- matrix(c(hor, vert), 
                ncol=2)
semPaths(MedSEM, 
         whatLabels="par",
         edge.label.cex = 1.5,
         edge.color = "black",
         residuals=FALSE,
         intercepts=FALSE,
         sizeMan=12, 
         sizeMan2=7, 
         layout=Place)
#
#Standardized Parameters
semPaths(MedSEM, 
         whatLabels="std",
         edge.label.cex = 1.5,
         edge.color = "black",
         residuals=FALSE,
         intercepts=FALSE,
         sizeMan=12, 
         sizeMan2=7, 
         layout=Place)
#
#
#Confirmatory Factor Analysis----
#Import data from Chapter 12 appendix
CFA_DF <- read.spss("Warner/bsri.sav", 
                 to.data.frame=TRUE, 
                 use.value.labels = FALSE)
#
BemMod <- 'BemFem=~warm+sympthtc+nurtrant
      BemMasc=~forceful+dominant+asertive'
BemCFA <- cfa(BemMod, data=CFA_DF)
summary(BemCFA, 
  fit.measures=TRUE)
BemCFA@test
semPaths(BemCFA, whatLabels="std", 
  edge.label.cex = 1.5,
  edge.color = "black")
#
#
#Latent-Variable SEM----
lvSEM <- read.spss("Warner/wbsocial.sav", 
    to.data.frame=TRUE, 
    use.value.labels = FALSE)
names(lvSEM)
#
WBmod <- 'WellBeing=~LIFE_SATISFACTION+PositiveAffectpast2weeks+HAPPINESS
WellBeing~PerceivedSocialStressCohen+OverallSocialSupportCohenISEL
NegativeAffectpast2weeks~PerceivedSocialStressCohen+OverallSocialSupportCohenISEL
NegativeAffectpast2weeks~~0*WellBeing'
#
WBsem <- sem(WBmod, 
          data=lvSEM)
summary(WBsem, 
    fit.measures=TRUE)
#
MIsem <- modindices(WBsem)
View(MIsem)
#Correlate error terms PA and NA
WBmod2 <- 'WellBeing=~LIFE_SATISFACTION+PositiveAffectpast2weeks+HAPPINESS
WellBeing~PerceivedSocialStressCohen+OverallSocialSupportCohenISEL
NegativeAffectpast2weeks~PerceivedSocialStressCohen+OverallSocialSupportCohenISEL
NegativeAffectpast2weeks~~0*WellBeing 
NegativeAffectpast2weeks~~PositiveAffectpast2weeks'
#
WBsem2 <- sem(WBmod2, 
             data=lvSEM)
summary(WBsem2, 
  fit.measures=TRUE)
#
hor2 <- c(1, 1, 1, 0, -1, -1, 0)
vert2 <- c(1, 0, -1, 2, 2, 0, 0)
WBplace <- matrix(c(hor2, vert2), 
                ncol=2)
WBlabs <- c("LS", "PA", "Happ", "NA", "Stress", "Support", "WellBeing")
semPaths(WBsem2, 
  whatLabels="std", 
  edge.label.cex = 1.5,
  edge.label.position=.2,
  edge.color = "black", 
  layout=WBplace,
  sizeMan=12, 
  sizeMan2=7,
  sizeLat=15, 
  sizeLat2=9,
  nodeLabels=WBlabs)
#
#Model Comparisons
vuongtest(WBsem, WBsem2, nested=TRUE)
anova(WBsem, WBsem2)
