#CHAPTER 15: Structural Eq. Mod
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("lavaan", "semPlot", 
          "nonnest2", "dplyr")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Disclosure and Satisfaction data----
SEM_DF <- read.csv("Avo_Disc_RelSat_ver2.csv", 
                      header=TRUE, 
                      na.strings=c("NA", " ", ""))
names(SEM_DF)
View(SEM_DF)
#
#Two-Factor Measurement Model----
RelSatMod_2 <- 'RelSatFac =~ RelSat + CoupleSat + SexSat
    Sharing =~ SelfConceal + Disclosure + Authenticity'
library(lavaan)
RelSatCFA_2 <- cfa(RelSatMod_2, data=SEM_DF, std.lv=TRUE)
summary(RelSatCFA_2,
        fit.measures=TRUE)
View(modindices(RelSatCFA_2))
library(semPlot)
#Initial Model Plot
semPaths(RelSatCFA_2, whatLabels="std", 
         edge.label.cex = 1.5,
         edge.color = "black", 
         sizeLat=13, sizeLat2=6, 
         sizeMan = 12, sizeMan2=6)
#Model Plot with Letter Labels
semPaths(RelSatCFA_2, whatLabels="std", 
  edge.label.cex = 1.5,
  edge.color = "black", 
  sizeLat=13, sizeLat2=6, 
  sizeMan = 12, sizeMan2=6, 
  nodeLabels=letters[1:8])
#Model Plot with Labels manually added
semPaths(RelSatCFA_2, whatLabels="std", 
  edge.label.cex = 1.5,
  edge.color = "black", 
  sizeLat=13, sizeLat2=6, 
  sizeMan = 12, sizeMan2=6,
  nodeLabels=c("RelSat","CoupSat",
        "SexSat","Conceal","Disclose",
        "Authentic","RelSatFac",
        "Sharing"))
#
#One-Factor Measurement Model----
RelSatMod_1 <- '
  RelFac =~ RelSat + CoupleSat + SexSat +
  SelfConceal + Disclosure + Authenticity'
RelSatCFA_1 <- cfa(RelSatMod_1, 
      data=SEM_DF, std.lv=TRUE)
summary(RelSatCFA_1, 
        fit.measures=TRUE)
#Model Plot
semPaths(RelSatCFA_1, 
  whatLabels="std", 
  edge.label.cex = 1.5,
  edge.color = "black", 
  sizeLat=13, sizeLat2=6, 
  sizeMan = 12, sizeMan2=6)
#Compare two models----
anova(RelSatCFA_2, RelSatCFA_1)
library(nonnest2)
vuongtest(RelSatCFA_2, RelSatCFA_1, nested=TRUE)
#
#Latent-Variable SEM----
LV_MedMod <- 'RelSatFac=~RelSat+CoupleSat+SexSat
  RelSatFac~c*AvoAtt
  Disclosure~a*AvoAtt
  RelSatFac~b*Disclosure
  indirect:=a*b
  total:=c+(a*b)'
LV_MedSEM <- sem(LV_MedMod, 
                 data=SEM_DF)
#Model Summary and Estimates
summary(LV_MedSEM, rsq=TRUE, 
        fit.measures=TRUE)
View(parameterEstimates(LV_MedSEM))
#Latent Variable Summary
library(dplyr)
View(parameterEstimates(LV_MedSEM, standardized=TRUE) %>% 
  filter(op == "=~") %>% 
  select("Lat Var"=lhs, Indicator=rhs, b=est, StdErr=se, Z=z, "p value"=pvalue, Beta=std.all))
#Path Model Summary
View(parameterEstimates(LV_MedSEM, standardized=TRUE) %>% 
       filter(op == ":=" | op == "~") %>% 
       select("Path"=label, b=est, StdErr=se, Z=z, "p value"=pvalue, Beta=std.all))
#
#Bootstrapped estimates
LV_MedSEMboot <- sem(LV_MedMod, 
  data=SEM_DF, 
  se="boot", 
  bootstrap=2000)
standardizedSolution(LV_MedSEMboot)
#
#Visualize Model
semPaths(LV_MedSEM)
#Improve plot 
semPaths(LV_MedSEM, 
  nodeLabels = letters[1:6])
#(Left to Right; Predictor to Outcome)
hor <- c(4, 4, 4, 2, 1, 3)
vert <- c(.5, 0, -.5, 1, 0, 0)
Place <- matrix(c(hor, vert), 
                ncol=2)
semLabs <- c("RelSat", "CpSat", 
      "SexSat", "Disclosure", 
      "AvoAtt", "RelSatFac")
semPaths(LV_MedSEM, 
  whatLabels="par",
  edge.label.cex = 1.5,
  edge.color = "black",
  residuals=FALSE,
  intercepts=FALSE,
  sizeMan=14, sizeMan2=7,
  sizeLat=18,sizeLat2=8,
  layout=Place, nodeLabels=semLabs)
#
#Standardized Parameters
hor2 <- c(2.3, 3, 3.7, 2, 1, 3)
vert2 <- c(-1, -1, -1, 1, 0, 0)
Place2 <- matrix(c(hor2, vert2), 
                ncol=2)
semPaths(LV_MedSEM, 
  whatLabels="std",
  edge.label.cex = 1.5,
  edge.color = "black",
  residuals=FALSE,
  intercepts=FALSE,
  sizeMan=18, sizeMan2=8,
  sizeLat=18, sizeLat2=8,
  label.cex=1.5,
  label.norm="OOOOOOOOOO",
  layout=Place2, nodeLabels=semLabs)