#CHAPTER 16: Binary Log Reg
#Install and attach packages----
PacMan <- function(pkg){new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])] 
if (length(new.pkg))         
  install.packages(new.pkg, dependencies = TRUE)     
sapply(pkg, library, character.only = TRUE)}
pkgs <- c("lmtest","aod", "ggplot2")
PacMan(pkgs)
#
#Set working directory if needed
setwd("C:/Users/.../Desktop/LearningR/IntroToR_vol2")
#
#Import Stay-Leave data----
Log_DF <- read.csv("StayLeave.csv", 
  header=TRUE, 
  na.strings=c("NA", " ", ""))
names(Log_DF)
View(Log_DF)
#
table(Log_DF$StayLeave, 
      Log_DF$HappyInRel)
#
#Binary Log---- 
LogMod <- glm(
  StayLeave~HappyInRel+SSS_Total, 
  data=Log_DF, family="binomial")
#
#Test overall model
library(lmtest)
lrtest(LogMod)
#
#Coefficients
round(LogMod$coefficients, 3)
#Test - Somewhat Happy Coefficient
library(aod)
wald.test(b=coef(LogMod), 
  Sigma=vcov(LogMod), Terms=2)
#Test - Yes Happy Coefficient
wald.test(b=coef(LogMod), 
  Sigma=vcov(LogMod), Terms=3)
#Test - SexSat Coefficient
wald.test(b=coef(LogMod), 
  Sigma=vcov(LogMod), Terms=4)
#
#Odds of Staying
round(exp(coef(LogMod)), 3)
#
#Estimated Probability of Staying
MsexSat <- mean(Log_DF$SSS_Total)
SDsexSat <- sd(Log_DF$SSS_Total)
StayExamp_DF <- data.frame(
  HappyInRel=c(rep("no",3), 
               rep("somewhat",3),
               rep("yes",3)),
   SSS_Total=rep(c((MsexSat-SDsexSat),
                   MsexSat,
                   (MsexSat+SDsexSat)),3))
StayExamp_DF$PredStay <- predict(LogMod, 
              StayExamp_DF, type="response")
StayExamp_DF$PredStayLeave <- ifelse(
  StayExamp_DF$PredStay<.5, "Leave","Stay")
View(StayExamp_DF)
#
ggplot(StayExamp_DF, 
       aes(x=SSS_Total, y=PredStay, 
           fill=HappyInRel)) +
  geom_bar(stat="identity", 
           position="dodge")